-------------------------------------------------------------------------------
--|> CONFIG
-------------------------------------------------------------------------------
--|> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local GetCVarDefault = GetCVarDefault
local LibStub = LibStub
local InterfaceOptionsFrameAddOnsListScrollBar = InterfaceOptionsFrameAddOnsListScrollBar
local InterfaceOptionsFrame_OpenToCategory = InterfaceOptionsFrame_OpenToCategory
local InCombatLockdown = InCombatLockdown
-------------------------------------------------------------------------------
--|> LIBS
-------------------------------------------------------------------------------
local AceConfig = LibStub("AceConfig-3.0")
local SM = LibStub("LibSharedMedia-3.0")
local sounds = SM:List("sound")
local wipe = wipe
local SetCVar = SetCVar
local _

-------------------------------------------------------------------------------
--|> SLASH COMMANDS
-------------------------------------------------------------------------------
local halt = false
local Smax
--=> Commands Option Table
-------------------------------------------------------------------------------
weizPVP.SlashCommands = {
    name = "Slash Commands",
    order = -3,
    type = "group",
    args = {
        intro = {
            name = "weizPVP Slash Commands",
            type = "description",
            order = 1,
            cmdHidden = true
        },
        config = {
            name = "config",
            desc = "Opens the configuration menu.",
            type = "execute",
            func = function()
                InterfaceOptionsFrame_OpenToCategory("|cffeaeaeaweiz|r|cffffa012PVP|r")
                _, Smax = InterfaceOptionsFrameAddOnsListScrollBar:GetMinMaxValues()
                InterfaceOptionsFrameAddOnsListScrollBar:SetValue(Smax)
                InterfaceOptionsFrame_OpenToCategory("|cffeaeaeaweiz|r|cffffa012PVP|r") --> Sent twice due to WoW bug
            end,
            guiHidden = true,
            order = 2
        },
        show = {
            name = "Show",
            desc = "Show the weizPVP window.",
            type = "execute",
            order = 3,
            func = function()
                if not InCombatLockdown() then
                    weizPVP.HeaderFrame:Show()
                    weizPVP.CoreFrame:Show()
                end
            end,
            dialogHidden = true
        },
        hide = {
            name = "Hide",
            desc = "Hide the weizPVP window.",
            type = "execute",
            order = 4,
            func = function()
                if not InCombatLockdown() then
                    weizPVP.HeaderFrame:Hide()
                    weizPVP.CoreFrame:Hide()
                end
            end,
            dialogHidden = true
        },
        lock = {
            name = "Lock",
            desc = "Toggle locking of the window's position and size.",
            type = "execute",
            order = 5,
            func = function()
                if not InCombatLockdown() then
                    if weizPVP.Options.Window.Locked == true then
                        weizPVP:SetWindowLocked(false)
                    else
                        weizPVP:SetWindowLocked(true)
                    end
                else
                    --> In Combat
                    weizPVP:PrintAddonMessage("Window can only be locked out of combat.")
                end
            end,
            dialogHidden = true
        },
        pin = {
            name = "Pin",
            desc = "Toggle pinning of the window.",
            type = "execute",
            order = 6,
            func = function()
                if weizPVP.Options.Window.Locked then
                    weizPVP:PrintAddonMessage("Window is currently |cffff3838LOCKED|r. Can not pin until unlocked.")
                else
                    weizPVP:TogglePinned()
                end
                -- weizPVP:SaveAddonData()
            end,
            dialogHidden = true
        },
        -- !! HIDDEN COMMANDS =========================================================
        --> DEBUG: Detects and manages ALL player characters; not just enemies.
        debug = {
            name = "DEBUG",
            desc = "Toggles DEBUG mode where ALL players of any factions are accepted as valid.",
            type = "execute",
            order = 60,
            func = function()
                if weizPVP.Options.DEBUG == true then
                    weizPVP.Options.DEBUG = false
                    weizPVP:ClearListData()
                    weizPVP:PrintAddonMessage("|cff37ff37DEBUG DISABLED|r.")
                    weizPVP:SetStatusBarMessage("> |cff37ff37DEBUG MODE OFF|r <", true, 1)
                else
                    weizPVP.Options.DEBUG = true
                    weizPVP:PrintAddonMessage("|cffff3838DEBUG ENABLED|r.")
                    weizPVP:SetStatusBarMessage("> |cffff3838DEBUG MODE ACTIVE|r <", nil, nil, true)
                end
                -- weizPVP:SaveAddonData()
            end,
            cmdHidden = true
        },
        --> RESETALL: Wipes EVERYTHING
        resetall = {
            name = "Reset All",
            desc = "Resets all settings and wipes player data",
            type = "execute",
            order = 61,
            func = function()
                weizPVP:ResetAll()
            end,
            cmdHidden = true
        },
        --> HALT
        halt = {
            name = "Halts all event processing.",
            desc = "Stops any additional processing from taking place related to data gathering and player detection.",
            type = "execute",
            order = 62,
            func = function()
                if halt == false then
                    halt = true
                    weizPVP:UnregisterEvent("NAME_PLATE_UNIT_ADDED", "NameplateAdded")
                    weizPVP:UnregisterEvent("NAME_PLATE_UNIT_REMOVED", "NameplateRemoved")
                    weizPVP:UnregisterEvent("COMBAT_LOG_EVENT_UNFILTERED", "CombatLogEvent")
                    weizPVP:UnregisterEvent("PLAYER_TARGET_CHANGED", "PlayerTargetEvent")
                    weizPVP:UnregisterEvent("UPDATE_MOUSEOVER_UNIT", "PlayerMouseoverEvent")
                    weizPVP:UnregisterEvent("UNIT_HEALTH", "UnitHealthEvent")
                    weizPVP:UnregisterEvent("PLAYER_LOGIN", "UpdateDisplayData")
                    weizPVP:PrintAddonMessage("|cffff3838EVENT PROCESSING HALTED:|r Run '/wpvp halt' again to resume.")
                else
                    if halt == true then
                        halt = false
                        weizPVP:RegisterEvent("NAME_PLATE_UNIT_ADDED", "NameplateAdded")
                        weizPVP:RegisterEvent("NAME_PLATE_UNIT_REMOVED", "NameplateRemoved")
                        weizPVP:RegisterEvent("COMBAT_LOG_EVENT_UNFILTERED", "CombatLogEvent")
                        weizPVP:RegisterEvent("PLAYER_TARGET_CHANGED", "PlayerTargetEvent")
                        weizPVP:RegisterEvent("UPDATE_MOUSEOVER_UNIT", "PlayerMouseoverEvent")
                        weizPVP:RegisterEvent("UNIT_HEALTH", "UnitHealthEvent")
                        weizPVP:RegisterEvent("PLAYER_LOGIN", "UpdateDisplayData")
                        weizPVP:PrintAddonMessage("|cff37ff37EVENT PROCESSING RESUMED.|r")
                    end
                end
            end,
            cmdHidden = true
        },
        --> RESET OPTIONS
        resetOptions = {
            name = "Reset Options",
            desc = "Resets all Options but doesn't change player data at all",
            type = "execute",
            order = 63,
            func = function()
                weizPVP:ResetOptions()
            end,
            cmdHidden = true
        },
        --> RESET PLAYER DB
        resetPlayerDB = {
            name = "Reset Player DB",
            desc = "Wipes the player database. Options remain untouched.",
            type = "execute",
            order = 64,
            func = function()
                weizPVP:ClearListData()
                if weizPVP.PlayerDB then
                    wipe(weizPVP.PlayerDB)
                end
                weizPVP.globalDB.PlayerDB = {}
            end,
            cmdHidden = true
        }
        -- !! END HIDDEN COMMANDS =====================================================
    }
}

--=> Register Slash Commands
-------------------------------------------------------------------------------
AceConfig:RegisterOptionsTable("weizPVP.SlashCommands", weizPVP.SlashCommands, {"wpvp", "weizpvp"})
-------------------------------------------------------------------------------
--|> INTERFACE OPTIONS: WOW GUI MENU
-------------------------------------------------------------------------------
--=> Options Table
-------------------------------------------------------------------------------

weizPVP.OptionsTable = {
    name = "|cffeaeaeaweiz|r|cffffa012PVP|r  |cffffffff/|r  v" .. weizPVP.Addon.VERSION,
    type = "group",
    args = {
        --> Overview Group
        -------------------------------------------
        overview = {
            name = "Overview",
            type = "group",
            order = 1,
            args = {
                introOverview = {
                    name = "|cffffa012OVERVIEW|r \n",
                    type = "header",
                    order = 1,
                    width = "full"
                },
                --> Window Tips
                -------------------------------------------
                windowTipsHeader = {
                    name = "|cffffa012Window Tips:|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 2
                },
                windowTips = {
                    type = "description",
                    name = " Pinning the Window:  |cff42dcf4Right Click|r  the title bar to toggle. \n" ..
                        " Locking the Window: Use  |cff42dcf4Ctrl + Right Click|r the title bar to toggle. \n",
                    width = "full",
                    order = 3
                },
                --> Commands
                -------------------------------------------
                commandsHeader = {
                    name = "|cffffa012Commands:|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 4
                },
                commands = {
                    type = "description",
                    name = " Show Window:  |cff42dcf4/wpvp show|r \n \n" ..
                        " Hide Window:  |cff42dcf4/wpvp hide|r \n \n" ..
                            " Lock Window:  |cff42dcf4/wpvp lock|r \n \n" ..
                                " Pin Window:  |cff42dcf4/wpvp pin|r \n \n" ..
                                    " Halt Event Processing:  |cff42dcf4/wpvp halt|r \n" ..
                                        "  - Halting will stop all player data collection (most of the addon's usage).",
                    width = "full",
                    order = 5
                }
            }
        },
        --> General Options Group
        -------------------------------------------
        general = {
            name = "General",
            type = "group",
            order = 2,
            args = {
                introGeneral = {
                    name = " |cffffa012GENERAL|r",
                    type = "header",
                    order = 1,
                    width = "full"
                },
                --> General Options
                -------------------------------------------
                lock = {
                    name = "Lock Window",
                    desc = "Lock the window's dimensions and prevent moving.",
                    type = "toggle",
                    width = "full",
                    order = 2,
                    get = function()
                        return weizPVP.Options.Window.Locked
                    end,
                    set = function(_, value)
                        if weizPVP.Options.Window.Locked == true then
                            weizPVP:SetWindowLocked(false)
                        else
                            weizPVP:SetWindowLocked(true)
                        end
                    end
                },
                EnableBGs = {
                    name = " Enabled in BGs",
                    desc = "Enable weizPVP in Battlegrounds.",
                    type = "toggle",
                    order = 3,
                    width = "full",
                    get = function()
                        return weizPVP.Options.Addon.EnabledInBattlegrounds
                    end,
                    set = function(_, value)
                        --> Double check that we were already disabled. If so, initialize addon again.
                        weizPVP.Options.Addon.EnabledInBattlegrounds = value
                        weizPVP.GetPVPZone()
                    end
                },
                EnableArenas = {
                    name = " Enabled in Arenas",
                    desc = "Enable weizPVP in Arenas.",
                    type = "toggle",
                    order = 4,
                    width = "full",
                    get = function()
                        return weizPVP.Options.Addon.EnabledInArena
                    end,
                    set = function(_, value)
                        --> Double check that we were already disabled. If so, initialize addon again.
                        weizPVP.Options.Addon.EnabledInArena = value
                        weizPVP.GetPVPZone()
                    end
                }
            }
        },
        --> Alerts Group
        -------------------------------------------
        alerts = {
            name = "Alerts",
            type = "group",
            order = 4,
            args = {
                introAlerts = {
                    name = " |cffffa012ALERTS & NOTIFICATIONS|r",
                    type = "header",
                    order = 1,
                    width = "full"
                },
                --> New player detected
                -------------------------------------------
                AlertDetectedSection = {
                    name = "\n |cffffa012On New Player Detection|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 2
                },
                AlertDetectedPlayer = {
                    name = " New Player Detected: Audio Alert",
                    desc = "Play's an alert when a new player is added to the enemy list." ..
                        "Plays the audio until it ends; doesnt not overlap with multiple detections.",
                    type = "toggle",
                    width = "full",
                    order = 3,
                    get = function()
                        return weizPVP.Options.AudioAlerts.DetectedPlayerSound
                    end,
                    set = function(_, value)
                        weizPVP.Options.AudioAlerts.DetectedPlayerSound = value
                    end
                },
                AlertDetectedPlayerSoundFile = {
                    type = "select",
                    name = " New Player Alert Sound",
                    desc = "The audio file that plays on detection of a new player.",
                    values = sounds,
                    width = "full",
                    order = 4,
                    get = function()
                        for i, v in next, sounds do
                            if v == weizPVP.Options.AudioAlerts.DetectedPlayerSoundFile then
                                return i
                            end
                        end
                    end,
                    set = function(_, value)
                        weizPVP.Options.AudioAlerts.DetectedPlayerSoundFile = sounds[value]
                    end,
                    itemControl = "DDI-Sound",
                    disabled = function()
                        return not weizPVP.Options.AudioAlerts.DetectedPlayerSound
                    end
                },
                --> Stealh
                stealthSection = {
                    name = "\n |cffffa012Stealth Options|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 5
                },
                StealthAlertEnabled = {
                    name = " Enable Stealth Alerts",
                    desc = "Show an alert when a unit is detected going stealth or invis.",
                    type = "toggle",
                    width = "full",
                    order = 6,
                    get = function()
                        return weizPVP.Options.StealthAlert.Enabled
                    end,
                    set = function(_, value)
                        weizPVP.Options.StealthAlert.Enabled = value
                    end
                },
                StealthAlertSoundEnabled = {
                    name = " Enable Stealth Audio Alert",
                    desc = "Plays a sound when players going stealth or invis while Stealth Alerts is enabled.",
                    type = "toggle",
                    width = "full",
                    order = 7,
                    get = function()
                        return weizPVP.Options.StealthAlert.EnableSound
                    end,
                    set = function(_, value)
                        weizPVP.Options.StealthAlert.EnableSound = value
                    end,
                    disabled = function()
                        return not weizPVP.Options.StealthAlert.Enabled
                    end
                },
                StealthAlertSoundFile = {
                    type = "select",
                    name = " Stealth Alert Sound",
                    desc = "The sound to play on stealth detection, if enabled.",
                    values = sounds,
                    width = "full",
                    order = 8,
                    get = function()
                        for i, v in next, sounds do
                            if v == weizPVP.Options.StealthAlert.SoundFile then
                                return i
                            end
                        end
                    end,
                    set = function(_, value)
                        weizPVP.Options.StealthAlert.SoundFile = sounds[value]
                    end,
                    itemControl = "DDI-Sound",
                    disabled = function()
                        if weizPVP.Options.StealthAlert.EnableSound == false or weizPVP.Options.StealthAlert.Enabled == false then
                            return true
                        else
                            return false
                        end
                    end
                }
            }
        },
        --> Crosshair Group
        -------------------------------------------
        crosshair = {
            name = "Crosshair",
            type = "group",
            order = 5,
            args = {
                intro = {
                    name = "|cffffa012CROSSHAIR|r",
                    type = "header",
                    order = 1,
                    width = "full"
                },
                --> Crosshair Options
                -------------------------------------------
                Enabled = {
                    name = " Enable Crosshairs",
                    desc = "Toggles the Crosshairs on/off",
                    type = "toggle",
                    width = "full",
                    order = 2,
                    get = function()
                        return weizPVP.Options.Crosshair.Enabled
                    end,
                    set = function(_, value)
                        if value == true then
                            weizPVP.Options.Crosshair.Enabled = true
                            weizPVP:EnableCrosshair()
                        else
                            weizPVP.Options.Crosshair.Enabled = false
                            weizPVP:DisableCrosshair()
                        end
                    end
                },
                Alpha = {
                    name = "Adjust Overall Alpha",
                    desc = "Change the overall Alpha of the Crosshair and it's elements.",
                    type = "range",
                    min = 0.1,
                    max = 1,
                    width = "full",
                    step = 0.1,
                    order = 3,
                    get = function()
                        return weizPVP.Options.Crosshair.Alpha
                    end,
                    set = function(_, value)
                        weizPVP.Options.Crosshair.Alpha = value
                        weizPVP:CrosshairAlphaAdjust(value)
                    end,
                    disabled = function()
                        return not weizPVP.Options.Crosshair.Enabled
                    end
                },
                --> Crosshair Tips
                -------------------------------------------
                TipsHeader = {
                    name = "\n|cffffa012Nameplate CVars:|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 4
                },
                Tips = {
                    type = "description",
                    name = "Use these options to apply optimal or default nameplate settings. \n" ..
                        "Other addons may change these values. If the crosshairs start acting up, try re-applying. \n",
                    order = 5
                },
                ApplyCVars = {
                    type = "execute",
                    name = "Apply Optimal Nameplate CVar values",
                    width = "full",
                    order = 6,
                    func = function()
                        SetCVar("nameplateMaxDistance", 100)
                        SetCVar("nameplateTargetRadialPosition", 1)
                        SetCVar("nameplateMaxScale", 1)
                        SetCVar("nameplateMinScale", 0.8)
                        SetCVar("nameplateSelectedScale", 1)
                        SetCVar("nameplateOtherTopInset", 0.1)
                        SetCVar("nameplateOtherBottomInset", 0.1)
                        SetCVar("nameplateLargeTopInset", 0.1)
                        SetCVar("nameplateLargeBottomInset", 0.15)
                    end
                },
                ResetCVars = {
                    type = "execute",
                    name = "Set Nameplate CVars to DEFAULT values",
                    width = "full",
                    order = 7,
                    func = function()
                        SetCVar("nameplateMaxDistance", GetCVarDefault("nameplateMaxDistance"))
                        SetCVar("nameplateTargetRadialPosition", GetCVarDefault("nameplateTargetRadialPosition"))
                        SetCVar("nameplateMaxScale", GetCVarDefault("nameplateMaxScale"))
                        SetCVar("nameplateMinScale", GetCVarDefault("nameplateMinScale"))
                        SetCVar("nameplateSelectedScale", GetCVarDefault("nameplateSelectedScale"))
                        SetCVar("nameplateOtherTopInset", GetCVarDefault("nameplateOtherTopInset"))
                        SetCVar("nameplateOtherBottomInset", GetCVarDefault("nameplateOtherBottomInset"))
                        SetCVar("nameplateLargeTopInset", GetCVarDefault("nameplateLargeTopInset"))
                        SetCVar("nameplateLargeBottomInset", GetCVarDefault("nameplateLargeBottomInset"))
                    end
                }
            }
        },
        --> BETA Group
        -------------------------------------------
        beta = {
            name = "|cffffa012BETA|r",
            type = "group",
            order = 6,
            args = {
                introBeta = {
                    name = " |cff42dcf4BETA|r \n",
                    type = "header",
                    order = 1,
                    width = "full"
                },
                descBeta = {
                    name = "The options in this section are |cFFF4564Dexperimental|r." ..
                        "\n|cFFF4564DEnabling these options may give errors " .. "and trigger bugs that effect other parts of the addon.|r",
                    type = "description",
                    order = 2,
                    width = "full"
                },
                introLagMode = {
                    name = "\n |cffffa012LagMode|r",
                    type = "description",
                    fontSize = "large",
                    width = "full",
                    order = 3
                },
                descLagMode = {
                    name = "Disables some data gathering functions resulting in less CPU usage." ..
                        "\n \n |cffffa012*|r This also means that there will be less updates for things like determining roles." ..
                            "\n \n |cffffa012*|r Health and death updates are the main priority. \n",
                    type = "description",
                    order = 4,
                    width = "full"
                },
                --> LagMode
                -------------------------------------------
                LagModeEnable = {
                    name = "LagMode: Enable",
                    desc = "Enable LagMode, which will dynamically adjust this addon's processing & CPU usage based on your curren FPS.",
                    type = "toggle",
                    order = 5,
                    width = "full",
                    get = function()
                        return weizPVP.Options.LagMode.Enabled
                    end,
                    set = function(_, value)
                        weizPVP.Options.LagMode.Enabled = value
                    end
                },
                LagModeFPSThreshold = {
                    name = "LagMode: FPS Threshold",
                    desc = "LagMode will only be activated when below this 'Frames Per Second' threshold.",
                    type = "range",
                    min = 10,
                    max = 120,
                    width = "full",
                    step = 1,
                    order = 6,
                    get = function()
                        return weizPVP.Options.LagMode.FPSThreshold
                    end,
                    set = function(_, value)
                        weizPVP.Options.LagMode.FPSThreshold = value
                    end,
                    disabled = function()
                        return not weizPVP.Options.LagMode.Enabled
                    end
                },
                LagModeHalt = {
                    name = "LagMode: Emergency Halt (@10 FPS)",
                    desc = "When enabled, all data processing will be halted when dropping below 10 frames per second. \n" ..
                        "When back above 10 fps, normal operation will continue.",
                    type = "toggle",
                    order = 7,
                    width = "full",
                    get = function()
                        return weizPVP.Options.LagMode.HaltEnabled
                    end,
                    set = function(_, value)
                        weizPVP.Options.LagMode.HaltEnabled = value
                    end,
                    disabled = function()
                        return not weizPVP.Options.LagMode.Enabled
                    end
                }
            }
        }
    }
}

LibStub("AceConfig-3.0"):RegisterOptionsTable("weizPVP.OptionsTable", weizPVP.OptionsTable)
LibStub("AceConfigDialog-3.0"):AddToBlizOptions("weizPVP.OptionsTable", "|cffeaeaeaweiz|r|cffffa012PVP|r")
-------------------------------------------------------------------------------
--|> APPLY OPTIONS
-------------------------------------------------------------------------------
function weizPVP:ApplySavedOptions()
    --> Set window location and dimentions
    weizPVP:SetCoreFramePosition(
        weizPVP.Options.Frames.X,
        weizPVP.Options.Frames.Y,
        weizPVP.Options.Frames.Width,
        weizPVP.Options.Frames.Height
    )
    --> Apply Locked and Pinned Settings
    -- weizPVP:SetWindowLocked(weizPVP.Options.Window.Locked)
    -- weizPVP:SetWindowPin(weizPVP.Options.Window.Pinned)
end
