-------------------------------------------------------------------------------
--|> INIT
--:: Loads saved options or applies defaults.
--:: Checks for database changes and applies updates when needed.
--:: Loads player data.
-------------------------------------------------------------------------------
--|> INIT WEIZPVP
-------------------------------------------------------------------------------
_G.weizPVP = LibStub("AceAddon-3.0"):NewAddon("weizPVP", "AceConsole-3.0", "AceEvent-3.0", "AceTimer-3.0")
-------------------------------------------------------------------------------
--|> UPVALUE GLOBALS
-------------------------------------------------------------------------------
local weizPVP = weizPVP
local UnitLevel = UnitLevel
local GetRealmName = GetRealmName
local GetUnitName = GetUnitName
local MAX_PLAYER_LEVEL_TABLE = MAX_PLAYER_LEVEL_TABLE
local GetExpansionLevel = GetExpansionLevel
local UnitFactionGroup = UnitFactionGroup
local select = select
local UIParent = UIParent
local GetScreenWidth = GetScreenWidth
local GetScreenHeight = GetScreenHeight
local GetFramerate = GetFramerate
local GetCVar = GetCVar
local LibStub = LibStub

-------------------------------------------------------------------------------
--|> Set Constants
-------------------------------------------------------------------------------
--> Addon Constants
weizPVP.Addon = {
    VERSION = "1.71.4",
    DB_VERSION = "3.0"
}

-------------------------------------------------------------------------------
--> Current Player Info
--: Holds infomation about the player's stats, game settings, system settings, etc.
--: Used when having to adjust UI elements, compare against other player's realms, levels, factions, etc
-------------------------------------------------------------------------------
--> Get Player Unit Info
weizPVP.Player = {}
weizPVP.Player.Level = UnitLevel("player")
--> player's level
weizPVP.Player.CurrentRealm = GetRealmName()
--> player's realm name
weizPVP.Player.Name = GetUnitName("player")
--> player's profile name
weizPVP.Player.Faction = select(1, UnitFactionGroup("player"))
--> Horde/Alliance
weizPVP.MaxPlayerLevel = MAX_PLAYER_LEVEL_TABLE[GetExpansionLevel()]

--> Get Display Info
weizPVP.Display = {}
weizPVP.Display.Width = GetScreenWidth()
weizPVP.Display.Height = GetScreenHeight()
weizPVP.Display.xFactor = (768 / weizPVP.Display.Width) * (weizPVP.Display.Width / weizPVP.Display.Height)
weizPVP.Display.yFactor = 768 / weizPVP.Display.Height
weizPVP.Display.UIScale = UIParent:GetScale()
weizPVP.Display.EffectiveScale = UIParent:GetEffectiveScale()
weizPVP.Display.CVarUiScale = GetCVar("uiScale")
weizPVP.Display.CurrentFPS = GetFramerate()

-------------------------------------------------------------------------------
--|> SHARED MEDIA
-------------------------------------------------------------------------------
local SM = LibStub:GetLibrary("LibSharedMedia-3.0")
--> Status Bars
SM:Register("STATUSBAR", "weizPVP: StatusBar", [[Interface\Addons\weizPVP\Media\Textures\bar-bg.tga]])
SM:Register("STATUSBAR", "weizPVP: StatusBar-Highlight", [[Interface\Addons\weizPVP\Media\Textures\bar-highlight.tga]])
SM:Register("STATUSBAR", "weizPVP: StatusBar-Notice", [[Interface\Addons\weizPVP\Media\Textures\bar-notice.tga]])
--> Bakgrounds
SM:Register("BACKGROUND", "weizPVP: Background", [[Interface\Addons\weizPVP\Media\Textures\white16x16.tga]])
SM:Register("BACKGROUND", "weizPVP: #FFFFFF", [[Interface\Addons\weizPVP\Media\Textures\white16x16.tga]])
SM:Register("BACKGROUND", "weizPVP: Bar-BG", [[Interface\Addons\weizPVP\Media\Textures\bar-bg.tga]])
SM:Register("BACKGROUND", "weizPVP: Gradient", [[Interface\Addons\weizPVP\Media\Textures\bar-grad.tga]])
--> Borders
SM:Register("BORDER", "weizPVP: Border", [[Interface\Addons\weizPVP\Media\Textures\white16x16.tga]])
--> Fonts
SM:Register("FONT", "Roboto Condensed Bold", [[Interface\Addons\weizPVP\Media\Fonts\RobotoCondensed-Bold.ttf]])
SM:Register("FONT", "Roboto Condensed BoldItalic", [[Interface\Addons\weizPVP\Media\Fonts\RobotoCondensed-BoldItalic.ttf]])
SM:Register("FONT", "Accidental Presidency", [[Interface\Addons\weizPVP\Media\Fonts\Accidental-Presidency.ttf]])
SM:Register("FONT", "Accidental Presidency Italic", [[Interface\Addons\weizPVP\Media\Fonts\Accidental-Presidency-Italic.ttf]])
SM:Register("FONT", "PT Sans", [[Interface\Addons\weizPVP\Media\Fonts\PTSans.ttf]])
--> Sounds
SM:Register("SOUND", "weizPVP: Beep 1", [[Interface\Addons\weizPVP\Media\Sounds\beep-1.ogg]])
SM:Register("SOUND", "weizPVP: Beep 2", [[Interface\Addons\weizPVP\Media\Sounds\beep-2.ogg]])
SM:Register("SOUND", "weizPVP: Error 1", [[Interface\Addons\weizPVP\Media\Sounds\error-1.ogg]])
SM:Register("SOUND", "weizPVP: Notice 1", [[Interface\Addons\weizPVP\Media\Sounds\notice-1.ogg]])
SM:Register("SOUND", "weizPVP: Notice 2", [[Interface\Addons\weizPVP\Media\Sounds\notice-2.ogg]])
SM:Register("SOUND", "weizPVP: Notice 3", [[Interface\Addons\weizPVP\Media\Sounds\notice-3.ogg]])
SM:Register("SOUND", "weizPVP: Warning 1", [[Interface\Addons\weizPVP\Media\Sounds\warning-1.ogg]])
SM:Register("SOUND", "weizPVP: Warning 2", [[Interface\Addons\weizPVP\Media\Sounds\warning-2.ogg]])
SM:Register("SOUND", "weizPVP: Warning 3", [[Interface\Addons\weizPVP\Media\Sounds\warning-3.ogg]])
SM:Register("SOUND", "weizPVP: Warning 4", [[Interface\Addons\weizPVP\Media\Sounds\warning-4.ogg]])
-------------------------------------------------------------------------------
--|> Create DataTables
-------------------------------------------------------------------------------
weizPVP.AbilityLevelDB = {}
weizPVP.SpecDB = {}
local function InitDataTables()
    --> CREATE ABILITY LEVEL DB
    -----------------------------------------------------------------------
    weizPVP.AbilityLevelDB = {
        [267102] = 30,
        [109142] = 45,
        [213010] = 98,
        [219713] = 98,
        [275544] = 1,
        [238082] = 98,
        [199111] = 1,
        [210764] = 56,
        [193647] = 1,
        [219450] = 1,
        [116011] = 45,
        [19882] = 4,
        [254467] = 1,
        [195380] = 1,
        [79140] = 56,
        [200850] = 1,
        [239307] = 1,
        [231876] = 63,
        [200586] = 40,
        [258925] = 102,
        [263135] = 78,
        [203566] = 1,
        [238084] = 1,
        [200851] = 1,
        [205320] = 1,
        [51271] = 57,
        [207289] = 100,
        [209539] = 1,
        [238083] = 1,
        [196864] = 15,
        [193644] = 1,
        [279524] = 1,
        [408] = 34,
        [201845] = 48,
        [53385] = 40,
        [20243] = 10,
        [271580] = 60,
        [238078] = 55,
        [202342] = 100,
        [189184] = 55,
        [200853] = 1,
        [146974] = 1,
        [264195] = 1,
        [197610] = 1,
        [269594] = 1,
        [132578] = 90,
        [276112] = 1,
        [241050] = 55,
        [287472] = 1,
        [199364] = 1,
        [213764] = 32,
        [193642] = 1,
        [248518] = 42,
        [200854] = 1,
        [30451] = 10,
        [883] = 1,
        [270651] = 1,
        [278594] = 1,
        [279525] = 1,
        [73325] = 63,
        [238080] = 55,
        [199365] = 1,
        [267115] = 15,
        [157153] = 90,
        [200855] = 1,
        [218979] = 55,
        [264199] = 1,
        [235365] = 30,
        [267116] = 15,
        [231633] = 58,
        [105174] = 10,
        [238079] = 55,
        [108209] = 30,
        [199366] = 1,
        [15590] = 1,
        [263642] = 104,
        [285485] = 58,
        [200856] = 1,
        [102793] = 30,
        [207061] = 57,
        [288466] = 1,
        [51986] = 61,
        [196884] = 75,
        [276056] = 1,
        [11416] = 42,
        [189180] = 55,
        [199367] = 1,
        [115080] = 32,
        [32375] = 80,
        [1064] = 20,
        [278603] = 55,
        [183218] = 24,
        [83243] = 34,
        [215982] = 40,
        [238073] = 1,
        [268175] = 110,
        [108208] = 30,
        [189179] = 55,
        [155672] = 100,
        [198111] = 40,
        [199849] = 90,
        [279536] = 1,
        [112965] = 24,
        [264] = 1,
        [238076] = 1,
        [12472] = 40,
        [55233] = 60,
        [263648] = 110,
        [171803] = 1,
        [81782] = 5,
        [51723] = 63,
        [193157] = 90,
        [109132] = 5,
        [198361] = 1,
        [210030] = 1,
        [56222] = 58,
        [186945] = 1,
        [262161] = 75,
        [231630] = 65,
        [5217] = 13,
        [104773] = 54,
        [207548] = 99,
        [197369] = 1,
        [200845] = 1,
        [279603] = 1,
        [210029] = 1,
        [10059] = 42,
        [55090] = 55,
        [227174] = 100,
        [238102] = 1,
        [193155] = 15,
        [202335] = 40,
        [231895] = 100,
        [20473] = 10,
        [272651] = 38,
        [203577] = 1,
        [164862] = 40,
        [190925] = 14,
        [205065] = 1,
        [238101] = 1,
        [197138] = 1,
        [204074] = 100,
        [207550] = 99,
        [285564] = 90,
        [219467] = 1,
        [279607] = 1,
        [155675] = 100,
        [274081] = 55,
        [195399] = 1,
        [191419] = 55,
        [220228] = 98,
        [270669] = 1,
        [131347] = 98,
        [288979] = 1,
        [192657] = 1,
        [86535] = 50,
        [199855] = 30,
        [207317] = 90,
        [212036] = 66,
        [238103] = 1,
        [197140] = 1,
        [194407] = 100,
        [288977] = 55,
        [209554] = 1,
        [202354] = 90,
        [195645] = 4,
        [261916] = 12,
        [212035] = 40,
        [220226] = 98,
        [208794] = 55,
        [204077] = 75,
        [14117] = 10,
        [270611] = 1,
        [2908] = 56,
        [228920] = 100,
        [238097] = 1,
        [188196] = 1,
        [197871] = 40,
        [208793] = 55,
        [274586] = 28,
        [206328] = 40,
        [188443] = 28,
        [196] = 1,
        [288056] = 1,
        [189186] = 55,
        [199377] = 1,
        [51124] = 55,
        [238100] = 30,
        [202589] = 40,
        [288988] = 1,
        [208065] = 1,
        [189185] = 55,
        [192422] = 1,
        [120360] = 90,
        [247543] = 54,
        [5225] = 1,
        [212040] = 66,
        [691] = 36,
        [208795] = 55,
        [204080] = 55,
        [187698] = 36,
        [246287] = 100,
        [214508] = 1,
        [279619] = 60,
        [238094] = 1,
        [56814] = 1,
        [79134] = 50,
        [276079] = 58,
        [279620] = 90,
        [210053] = 40,
        [91023] = 15,
        [32266] = 42,
        [202095] = 60,
        [238093] = 1,
        [278130] = 1,
        [86538] = 50,
        [198123] = 40,
        [31209] = 58,
        [200373] = 1,
        [47568] = 57,
        [204330] = 40,
        [194153] = 12,
        [853] = 8,
        [51462] = 55,
        [206315] = 75,
        [29722] = 14,
        [596] = 28,
        [213017] = 98,
        [212524] = 55,
        [191427] = 98,
        [274596] = 1,
        [202345] = 75,
        [111240] = 15,
        [172] = 3,
        [210802] = 45,
        [53576] = 35,
        [238095] = 1,
        [86539] = 50,
        [267211] = 15,
        [115072] = 50,
        [48484] = 54,
        [278571] = 1,
        [215768] = 40,
        [274598] = 1,
        [204596] = 98,
        [238090] = 1,
        [232876] = 40,
        [287506] = 52,
        [214776] = 1,
        [194662] = 57,
        [203340] = 40,
        [278569] = 1,
        [212526] = 55,
        [254475] = 1,
        [202347] = 90,
        [267214] = 100,
        [238089] = 1,
        [207311] = 56,
        [86536] = 55,
        [127757] = 40,
        [19885] = 4,
        [278138] = 1,
        [199384] = 1,
        [267215] = 100,
        [57994] = 18,
        [209548] = 1,
        [254474] = 1,
        [267216] = 90,
        [238092] = 1,
        [57870] = 1,
        [276154] = 1,
        [105424] = 28,
        [1966] = 44,
        [198128] = 63,
        [276153] = 1,
        [227688] = 1,
        [279070] = 1,
        [238091] = 1,
        [86537] = 55,
        [195650] = 1,
        [227687] = 1,
        [204336] = 40,
        [263186] = 50,
        [61305] = 60,
        [198145] = 40,
        [210805] = 100,
        [200861] = 1,
        [207068] = 1,
        [280132] = 55,
        [227686] = 1,
        [120225] = 50,
        [238118] = 98,
        [288570] = 1,
        [204089] = 1,
        [192428] = 1,
        [197386] = 1,
        [192923] = 1,
        [286587] = 1,
        [206572] = 40,
        [115203] = 55,
        [131113] = 1,
        [275602] = 1,
        [227685] = 1,
        [5171] = 90,
        [1776] = 34,
        [241090] = 98,
        [238117] = 98,
        [278145] = 1,
        [279080] = 1,
        [53376] = 90,
        [286585] = 1,
        [200863] = 1,
        [118] = 8,
        [17962] = 10,
        [198877] = 40,
        [286586] = 1,
        [238120] = 1,
        [220244] = 98,
        [34477] = 42,
        [235870] = 60,
        [246806] = 40,
        [288573] = 1,
        [239106] = 55,
        [231642] = 52,
        [278645] = 1,
        [238119] = 1,
        [212283] = 36,
        [279084] = 1,
        [126] = 24,
        [233396] = 55,
        [76613] = 78,
        [217996] = 104,
        [279081] = 1,
        [238114] = 55,
        [212051] = 66,
        [241091] = 98,
        [210065] = 40,
        [114014] = 10,
        [269650] = 100,
        [115069] = 16,
        [194917] = 60,
        [199640] = 1,
        [213047] = 1,
        [232893] = 99,
        [231644] = 42,
        [279584] = 98,
        [59057] = 59,
        [982] = 1,
        [27243] = 38,
        [280143] = 55,
        [194916] = 56,
        [260708] = 22,
        [279581] = 98,
        [224468] = 55,
        [239107] = 55,
        [51128] = 56,
        [238116] = 55,
        [121411] = 100,
        [279582] = 98,
        [183752] = 98,
        [199890] = 40,
        [254233] = 1,
        [207321] = 75,
        [224467] = 55,
        [212552] = 75,
        [93402] = 16,
        [183997] = 78,
        [190456] = 36,
        [238115] = 55,
        [12846] = 78,
        [214027] = 20,
        [197160] = 1,
        [287093] = 1,
        [111898] = 90,
        [202110] = 40,
        [218989] = 55,
        [238110] = 1,
        [183998] = 50,
        [273134] = 1,
        [236628] = 15,
        [278659] = 1,
        [57330] = 57,
        [194913] = 90,
        [196416] = 1,
        [199892] = 40,
        [216274] = 1,
        [209573] = 1,
        [238109] = 1,
        [6343] = 14,
        [224968] = 1,
        [287097] = 1,
        [279589] = 1,
        [238112] = 1,
        [197147] = 55,
        [200390] = 75,
        [205604] = 98,
        [235893] = 98,
        [108853] = 3,
        [231665] = 42,
        [197908] = 45,
        [238111] = 1,
        [194679] = 60,
        [278661] = 1,
        [276117] = 1,
        [191442] = 55,
        [35395] = 1,
        [194431] = 1,
        [238106] = 1,
        [202626] = 40,
        [200128] = 15,
        [46968] = 50,
        [29893] = 66,
        [196412] = 15,
        [51052] = 55,
        [274694] = 1,
        [197646] = 100,
        [231667] = 26,
        [266] = 1,
        [109248] = 75,
        [44457] = 90,
        [185245] = 98,
        [278107] = 55,
        [241110] = 1,
        [190449] = 1,
        [238108] = 1,
        [202628] = 1,
        [192447] = 55,
        [228431] = 70,
        [220240] = 98,
        [195419] = 1,
        [115989] = 57,
        [210323] = 58,
        [199153] = 1,
        [201372] = 48,
        [196162] = 40,
        [219744] = 98,
        [8936] = 5,
        [212048] = 66,
        [108194] = 58,
        [18960] = 14,
        [157444] = 10,
        [209566] = 1,
        [210557] = 1,
        [29166] = 50,
        [11426] = 26,
        [51514] = 42,
        [121536] = 30,
        [73313] = 55,
        [157443] = 1,
        [263716] = 60,
        [207348] = 1,
        [215273] = 1,
        [203624] = 40,
        [279172] = 1,
        [49143] = 55,
        [192939] = 102,
        [262228] = 90,
        [190462] = 1,
        [157442] = 1,
        [32271] = 17,
        [207347] = 98,
        [272718] = 55,
        [238133] = 1,
        [277681] = 1,
        [205596] = 98,
        [272717] = 1,
        [227692] = 1,
        [231657] = 42,
        [195679] = 90,
        [197900] = 15,
        [279672] = 1,
        [196422] = 1,
        [200383] = 15,
        [272719] = 55,
        [233411] = 55,
        [199887] = 1,
        [199158] = 1,
        [269245] = 1,
        [238135] = 1,
        [78203] = 38,
        [195182] = 55,
        [215773] = 1,
        [80313] = 100,
        [233412] = 55,
        [202386] = 1,
        [157447] = 1,
        [238130] = 1,
        [207352] = 98,
        [53563] = 20,
        [100130] = 45,
        [227689] = 1,
        [197406] = 1,
        [81229] = 55,
        [197] = 1,
        [278124] = 1,
        [241102] = 1,
        [238129] = 1,
        [126819] = 1,
        [273221] = 30,
        [190457] = 1,
        [198664] = 90,
        [157445] = 1,
        [210579] = 1,
        [241101] = 1,
        [200402] = 1,
        [199642] = 55,
        [211309] = 1,
        [123779] = 1,
        [49530] = 60,
        [274156] = 57,
        [116645] = 12,
        [105809] = 75,
        [62158] = 55,
        [279181] = 1,
        [238131] = 1,
        [196912] = 28,
        [215796] = 1,
        [210086] = 58,
        [53428] = 55,
        [219272] = 45,
        [192453] = 55,
        [213062] = 1,
        [236147] = 40,
        [238126] = 1,
        [269751] = 90,
        [218280] = 55,
        [43265] = 56,
        [279684] = 1,
        [213051] = 1,
        [193195] = 15,
        [196432] = 1,
        [263795] = 1,
        [269256] = 1,
        [238125] = 1,
        [197162] = 1,
        [288121] = 1,
        [208598] = 55,
        [212817] = 98,
        [132627] = 90,
        [100784] = 3,
        [238128] = 1,
        [5009] = 1,
        [280184] = 1,
        [213049] = 1,
        [215799] = 1,
        [196430] = 1,
        [192450] = 55,
        [279685] = 1,
        [241100] = 1,
        [238127] = 1,
        [280182] = 1,
        [288125] = 1,
        [200407] = 1,
        [213050] = 1,
        [196429] = 1,
        [57986] = 1,
        [190467] = 1,
        [212819] = 98,
        [231682] = 36,
        [238122] = 1,
        [269262] = 1,
        [241099] = 1,
        [127344] = 55,
        [259495] = 20,
        [198158] = 40,
        [209577] = 1,
        [213055] = 1,
        [193455] = 1,
        [236144] = 45,
        [238121] = 1,
        [207343] = 98,
        [192464] = 55,
        [17364] = 20,
        [28272] = 60,
        [267217] = 100,
        [277706] = 1,
        [204366] = 40,
        [210571] = 1,
        [212821] = 98,
        [15407] = 10,
        [238124] = 1,
        [49206] = 100,
        [199665] = 1,
        [133] = 10,
        [275722] = 1,
        [48743] = 75,
        [105805] = 10,
        [203638] = 1,
        [214795] = 98,
        [241125] = 1,
        [238123] = 1,
        [200395] = 1,
        [921] = 13,
        [234153] = 13,
        [272684] = 55,
        [279636] = 1,
        [2641] = 10,
        [280195] = 60,
        [259491] = 12,
        [633] = 55,
        [275726] = 1,
        [210341] = 40,
        [213571] = 1,
        [49998] = 55,
        [275725] = 1,
        [287081] = 55,
        [192460] = 55,
        [198675] = 40,
        [204385] = 40,
        [196922] = 30,
        [119811] = 1,
        [203129] = 40,
        [196439] = 40,
        [202384] = 1,
        [155228] = 10,
        [280199] = 1,
        [277651] = 1,
        [197419] = 75,
        [279637] = 1,
        [110959] = 65,
        [279141] = 1,
        [263814] = 1,
        [212081] = 48,
        [241121] = 1,
        [236662] = 63,
        [260248] = 60,
        [186263] = 28,
        [202137] = 101,
        [288084] = 1,
        [170374] = 15,
        [255260] = 100,
        [275670] = 1,
        [277656] = 1,
        [212084] = 108,
        [241124] = 1,
        [192457] = 55,
        [280203] = 1,
        [202138] = 106,
        [235903] = 98,
        [204883] = 75,
        [207104] = 57,
        [275672] = 1,
        [263818] = 1,
        [238146] = 1,
        [277658] = 1,
        [278715] = 1,
        [279642] = 1,
        [199408] = 40,
        [28271] = 60,
        [81749] = 20,
        [45438] = 50,
        [9077] = 1,
        [279647] = 1,
        [198912] = 40,
        [215061] = 1,
        [202900] = 40,
        [238145] = 1,
        [196926] = 15,
        [278713] = 1,
        [131894] = 60,
        [220279] = 1,
        [275673] = 1,
        [263821] = 1,
        [147784] = 1,
        [113860] = 100,
        [212816] = 98,
        [213573] = 1,
        [179057] = 98,
        [278719] = 1,
        [279646] = 1,
        [280205] = 1,
        [193213] = 55,
        [231437] = 1,
        [115315] = 60,
        [185763] = 10,
        [192222] = 60,
        [238147] = 1,
        [260243] = 30,
        [288091] = 1,
        [200652] = 1,
        [210333] = 1,
        [278718] = 1,
        [189744] = 1,
        [238142] = 1,
        [16931] = 34,
        [9116] = 1,
        [186257] = 22,
        [198434] = 1,
        [278223] = 68,
        [209341] = 1,
        [63268] = 1,
        [86108] = 50,
        [241114] = 1,
        [238141] = 1,
        [159456] = 38,
        [199428] = 40,
        [260241] = 30,
        [200421] = 1,
        [278721] = 1,
        [277234] = 90,
        [287599] = 40,
        [281208] = 56,
        [207358] = 1,
        [125883] = 1,
        [238144] = 1,
        [19879] = 4,
        [262837] = 3,
        [93375] = 10,
        [205636] = 15,
        [278727] = 1,
        [187264] = 1,
        [207126] = 100,
        [262838] = 52,
        [202890] = 1,
        [108968] = 40,
        [16974] = 80,
        [98008] = 56,
        [238143] = 1,
        [204147] = 1,
        [248580] = 1,
        [198670] = 100,
        [20608] = 26,
        [204875] = 55,
        [203651] = 40,
        [262840] = 36,
        [188006] = 1,
        [238138] = 1,
        [188501] = 98,
        [241115] = 1,
        [203155] = 40,
        [58642] = 55,
        [212339] = 1,
        [183778] = 75,
        [276741] = 40,
        [202162] = 40,
        [191721] = 55,
        [115310] = 70,
        [108839] = 30,
        [238137] = 1,
        [200409] = 1,
        [264332] = 30,
        [113724] = 75,
        [202163] = 30,
        [269297] = 1,
        [236153] = 40,
        [33076] = 50,
        [186270] = 1,
        [188499] = 98,
        [238140] = 1,
        [191488] = 55,
        [204150] = 90,
        [117952] = 18,
        [214326] = 1,
        [210590] = 1,
        [1850] = 8,
        [238139] = 1,
        [278736] = 98,
        [193468] = 78,
        [34861] = 40,
        [255544] = 100,
        [233673] = 70,
        [280161] = 1,
        [267316] = 78,
        [205626] = 98,
        [278676] = 1,
        [270233] = 90,
        [187258] = 1,
        [115308] = 20,
        [269737] = 15,
        [196937] = 15,
        [88625] = 16,
        [186265] = 70,
        [263346] = 45,
        [178819] = 58,
        [191485] = 55,
        [205625] = 98,
        [196938] = 15,
        [272782] = 1,
        [113858] = 100,
        [190493] = 1,
        [214081] = 1,
        [200414] = 1,
        [19880] = 4,
        [211106] = 1,
        [202168] = 15,
        [190740] = 78,
        [191731] = 55,
        [35715] = 62,
        [189749] = 1,
        [205627] = 98,
        [86113] = 55,
        [272721] = 55,
        [196707] = 45,
        [194224] = 1,
        [212827] = 98,
        [263786] = 1,
        [278683] = 1,
        [229976] = 1,
        [198] = 1,
        [280169] = 1,
        [205630] = 98,
        [22812] = 26,
        [273284] = 1,
        [211108] = 1,
        [132157] = 33,
        [278681] = 1,
        [215573] = 45,
        [273283] = 1,
        [205629] = 98,
        [42650] = 82,
        [212829] = 98,
        [263790] = 1,
        [24858] = 16,
        [207383] = 15,
        [287681] = 40,
        [137619] = 45,
        [280173] = 1,
        [6197] = 16,
        [203413] = 1,
        [115175] = 10,
        [158476] = 75,
        [280174] = 1,
        [287126] = 1,
        [200931] = 24,
        [157980] = 60,
        [202157] = 45,
        [262304] = 55,
        [279245] = 1,
        [202918] = 1,
        [206642] = 63,
        [190503] = 1,
        [191494] = 55,
        [189760] = 1,
        [195457] = 22,
        [273292] = 1,
        [194466] = 12,
        [191741] = 55,
        [273291] = 1,
        [50842] = 56,
        [191493] = 1,
        [236180] = 40,
        [231719] = 42,
        [205385] = 75,
        [212354] = 1,
        [102359] = 60,
        [191740] = 1,
        [115173] = 30,
        [162452] = 15,
        [257284] = 60,
        [200174] = 90,
        [202424] = 40,
        [199445] = 40,
        [201664] = 40,
        [235941] = 80,
        [266779] = 40,
        [207142] = 60,
        [189757] = 1,
        [200175] = 98,
        [212356] = 48,
        [273236] = 98,
        [215568] = 15,
        [185791] = 20,
        [76856] = 78,
        [31935] = 10,
        [275779] = 3,
        [202907] = 1,
        [47476] = 55,
        [241131] = 1,
        [158478] = 75,
        [97462] = 80,
        [279193] = 1,
        [273238] = 98,
        [200440] = 1,
        [55078] = 55,
        [272742] = 1,
        [219786] = 58,
        [273237] = 98,
        [221775] = 55,
        [158477] = 75,
        [227481] = 1,
        [210108] = 1,
        [212358] = 1,
        [185789] = 20,
        [279754] = 1,
        [157981] = 30,
        [203669] = 1,
        [189754] = 1,
        [273239] = 98,
        [267344] = 28,
        [272743] = 1,
        [203173] = 55,
        [191504] = 1,
        [197199] = 1,
        [187276] = 1,
        [248855] = 80,
        [287637] = 1,
        [203670] = 1,
        [125872] = 1,
        [55342] = 45,
        [221773] = 1,
        [218567] = 1,
        [192246] = 90,
        [279203] = 1,
        [116095] = 16,
        [199202] = 40,
        [8092] = 10,
        [196704] = 60,
        [47541] = 55,
        [288204] = 1,
        [152279] = 100,
        [189768] = 1,
        [279201] = 1,
        [219557] = 1,
        [88342] = 85,
        [257541] = 60,
        [152280] = 90,
        [196721] = 45,
        [116092] = 28,
        [19878] = 4,
        [213340] = 1,
        [219062] = 1,
        [187287] = 1,
        [214826] = 1,
        [3561] = 17,
        [200430] = 1,
        [4987] = 22,
        [77513] = 78,
        [205148] = 30,
        [202665] = 1,
        [191747] = 55,
        [191499] = 1,
        [137384] = 42,
        [152278] = 100,
        [1022] = 48,
        [202433] = 1,
        [205147] = 40,
        [213602] = 44,
        [279708] = 12,
        [205411] = 104,
        [194487] = 1,
        [277719] = 1,
        [219809] = 58,
        [287650] = 1,
        [221536] = 56,
        [257537] = 60,
        [287649] = 1,
        [236696] = 40,
        [204157] = 98,
        [99] = 28,
        [196725] = 90,
        [287656] = 1,
        [33206] = 48,
        [241150] = 1,
        [224764] = 1,
        [262395] = 30,
        [279712] = 1,
        [191760] = 55,
        [212613] = 98,
        [191512] = 1,
        [77515] = 78,
        [211126] = 1,
        [272824] = 1,
        [287653] = 1,
        [199954] = 40,
        [186788] = 1,
        [207385] = 90,
        [86092] = 50,
        [107] = 1,
        [241152] = 1,
        [196217] = 1,
        [267798] = 15,
        [204160] = 55,
        [280209] = 1,
        [1953] = 16,
        [77514] = 78,
        [273262] = 1,
        [102351] = 15,
        [186289] = 54,
        [194234] = 1,
        [263829] = 1,
        [217832] = 98,
        [207387] = 98,
        [86093] = 50,
        [3565] = 17,
        [6795] = 13,
        [279720] = 1,
        [137639] = 50,
        [273263] = 1,
        [241145] = 1,
        [213857] = 40,
        [210631] = 1,
        [147072] = 1,
        [25780] = 10,
        [202425] = 15,
        [202922] = 75,
        [22842] = 40,
        [288164] = 1,
        [241148] = 1,
        [273330] = 1,
        [71] = 1,
        [202426] = 1,
        [273329] = 1,
        [189772] = 1,
        [192249] = 60,
        [241147] = 1,
        [88344] = 85,
        [120581] = 1,
        [51564] = 34,
        [280772] = 100,
        [262150] = 100,
        [280211] = 1,
        [115295] = 100,
        [190514] = 1,
        [235463] = 30,
        [155271] = 75,
        [15286] = 28,
        [202751] = 100,
        [152277] = 100,
        [46924] = 90,
        [280392] = 90,
        [287730] = 1,
        [197214] = 90,
        [248621] = 90,
        [273334] = 1,
        [236279] = 90,
        [273308] = 1,
        [125732] = 1,
        [216331] = 90,
        [204909] = 104,
        [196718] = 100,
        [202428] = 40,
        [197711] = 1,
        [202572] = 90,
        [118000] = 90,
        [254465] = 1,
        [124146] = 1,
        [76857] = 78,
        [274823] = 1,
        [106839] = 70,
        [262111] = 78,
        [845] = 75,
        [184367] = 12,
        [85288] = 20,
        [268243] = 75,
        [236186] = 40,
        [231725] = 38,
        [215571] = 75,
        [221703] = 54,
        [23920] = 70,
        [213915] = 70,
        [236308] = 65,
        [227847] = 65,
        [86096] = 50,
        [204054] = 90,
        [280001] = 60,
        [208154] = 60,
        [273338] = 1,
        [202561] = 60,
        [260895] = 100,
        [197690] = 60,
        [871] = 55,
        [280721] = 45,
        [203316] = 30,
        [202430] = 15,
        [86110] = 50,
        [86101] = 50,
        [89401] = 1,
        [271788] = 15,
        [1719] = 50,
        [206649] = 98,
        [167105] = 50,
        [199023] = 48,
        [197729] = 1,
        [1160] = 48,
        [219573] = 1,
        [772] = 45,
        [278737] = 1,
        [20066] = 45,
        [16870] = 10,
        [197233] = 1,
        [273339] = 1,
        [211119] = 1,
        [108199] = 64,
        [205545] = 28,
        [279793] = 1,
        [86097] = 50,
        [196737] = 100,
        [210128] = 55,
        [202560] = 45,
        [64843] = 70,
        [203673] = 1,
        [277959] = 1,
        [199220] = 1,
        [207255] = 1,
        [203177] = 100,
        [197234] = 1,
        [254225] = 1,
        [236320] = 40,
        [1329] = 40,
        [213691] = 40,
        [270061] = 100,
        [213871] = 40,
        [768] = 8,
        [3566] = 17,
        [199261] = 40,
        [209400] = 99,
        [199127] = 40,
        [202200] = 65,
        [199086] = 40,
        [286573] = 1,
        [187304] = 1,
        [196418] = 1,
        [58640] = 55,
        [199454] = 40,
        [198228] = 1,
        [199] = 1,
        [210378] = 40,
        [109215] = 75,
        [212628] = 40,
        [34433] = 40,
        [274771] = 1,
        [198500] = 40,
        [190411] = 40,
        [231722] = 70,
        [187301] = 1,
        [210873] = 42,
        [272788] = 1,
        [106832] = 12,
        [210146] = 1,
        [279302] = 90,
        [108271] = 52,
        [278142] = 1,
        [287268] = 1,
        [118038] = 36,
        [278748] = 1,
        [199719] = 55,
        [264348] = 60,
        [231834] = 34,
        [184783] = 34,
        [703] = 12,
        [194007] = 1,
        [275334] = 15,
        [184575] = 20,
        [1715] = 32,
        [193759] = 14,
        [103827] = 30,
        [199456] = 40,
        [280450] = 40,
        [223657] = 30,
        [50977] = 55,
        [203201] = 30,
        [199720] = 55,
        [204934] = 40,
        [227344] = 40,
        [12975] = 32,
        [231830] = 28,
        [207946] = 1,
        [275336] = 45,
        [102342] = 54,
        [272792] = 1,
        [195244] = 1,
        [264351] = 1,
        [196684] = 1,
        [196437] = 1,
        [115288] = 45,
        [235224] = 75,
        [6552] = 24,
        [278752] = 1,
        [201459] = 98,
        [264352] = 1,
        [219831] = 98,
        [207666] = 106,
        [6572] = 22,
        [274281] = 100,
        [275338] = 75,
        [269379] = 1,
        [7384] = 20,
        [210147] = 1,
        [264353] = 1,
        [190784] = 28,
        [2565] = 20,
        [57755] = 17,
        [235450] = 26,
        [269380] = 1,
        [201460] = 98,
        [29725] = 15,
        [264354] = 15,
        [262231] = 15,
        [260643] = 15,
        [202603] = 15,
        [196976] = 100,
        [238686] = 55,
        [279806] = 1,
        [183416] = 60,
        [184361] = 14,
        [355] = 13,
        [197721] = 100,
        [280719] = 100,
        [275339] = 75,
        [203264] = 40,
        [212631] = 1,
        [23922] = 10,
        [23881] = 10,
        [12294] = 10,
        [278350] = 60,
        [77493] = 78,
        [163201] = 8,
        [34428] = 5,
        [196834] = 38,
        [51505] = 12,
        [88163] = 1,
        [235219] = 52,
        [214372] = 1,
        [68164] = 1,
        [196406] = 14,
        [58099] = 1,
        [199212] = 1,
        [272797] = 1,
        [194002] = 1,
        [197766] = 1,
        [288452] = 1,
        [288087] = 1,
        [101545] = 48,
        [197490] = 45,
        [216855] = 40,
        [288085] = 1,
        [213116] = 1,
        [196730] = 90,
        [288080] = 1,
        [288060] = 1,
        [210256] = 40,
        [281238] = 100,
        [220083] = 98,
        [278760] = 1,
        [201463] = 98,
        [287377] = 1,
        [77492] = 78,
        [193753] = 14,
        [273298] = 1,
        [185314] = 54,
        [192514] = 55,
        [190780] = 55,
        [283810] = 1,
        [77756] = 40,
        [280747] = 40,
        [279632] = 1,
        [279423] = 1,
        [279202] = 1,
        [213610] = 40,
        [199214] = 1,
        [201464] = 98,
        [279006] = 1,
        [278326] = 103,
        [278999] = 1,
        [278991] = 1,
        [101546] = 40,
        [197492] = 45,
        [194016] = 1,
        [212619] = 40,
        [280745] = 40,
        [200859] = 1,
        [278826] = 1,
        [278824] = 1,
        [274356] = 1,
        [281242] = 100,
        [278757] = 1,
        [274594] = 1,
        [108281] = 75,
        [278122] = 1,
        [288755] = 1,
        [235711] = 75,
        [77495] = 78,
        [190778] = 55,
        [187310] = 1,
        [196492] = 1,
        [85948] = 55,
        [275632] = 1,
        [288754] = 98,
        [189787] = 1,
        [202940] = 1,
        [275532] = 1,
        [287280] = 1,
        [207407] = 98,
        [260285] = 90,
        [104316] = 14,
        [280752] = 58,
        [33786] = 40,
        [152261] = 15,
        [206416] = 106,
        [55095] = 55,
        [273412] = 1,
        [190529] = 1,
        [280749] = 40,
        [202753] = 1,
        [194509] = 52,
        [197727] = 1,
        [248579] = 1,
        [162488] = 60,
        [108280] = 80,
        [3127] = 1,
        [196419] = 1,
        [155783] = 78,
        [197231] = 1,
        [53595] = 10,
        [238149] = 1,
        [238148] = 1,
        [271877] = 100,
        [245388] = 90,
        [238113] = 1,
        [77758] = 12,
        [238077] = 1,
        [202445] = 1,
        [238075] = 1,
        [231842] = 1,
        [206930] = 55,
        [278766] = 98,
        [228378] = 1,
        [106830] = 12,
        [216273] = 1,
        [216272] = 1,
        [196489] = 1,
        [214939] = 1,
        [247675] = 80,
        [223817] = 100,
        [219592] = 1,
        [211829] = 1,
        [287707] = 1,
        [210637] = 1,
        [273307] = 1,
        [205191] = 75,
        [197000] = 40,
        [209559] = 1,
        [209541] = 1,
        [108283] = 30,
        [216113] = 40,
        [209494] = 1,
        [145108] = 34,
        [119381] = 52,
        [196985] = 100,
        [219093] = 1,
        [48263] = 55,
        [201454] = 98,
        [203704] = 98,
        [280373] = 15,
        [209481] = 1,
        [198100] = 70,
        [274366] = 1,
        [82246] = 55,
        [209472] = 1,
        [212642] = 1,
        [209462] = 1,
        [210144] = 1,
        [209459] = 1,
        [203576] = 1,
        [194093] = 42,
        [203261] = 1,
        [203953] = 15,
        [203230] = 1,
        [201455] = 98,
        [287711] = 1,
        [200726] = 40,
        [77130] = 22,
        [274368] = 1,
        [206931] = 56,
        [203225] = 1,
        [5019] = 1,
        [204945] = 1,
        [211881] = 108,
        [200875] = 1,
        [221562] = 55,
        [214626] = 1,
        [205180] = 58,
        [200872] = 1,
        [5143] = 12,
        [201456] = 98,
        [200871] = 1,
        [200870] = 1,
        [195263] = 1,
        [273313] = 1,
        [200860] = 1,
        [264874] = 75,
        [278840] = 1,
        [115151] = 20,
        [162243] = 98,
        [200857] = 1,
        [200849] = 1,
        [200847] = 1,
        [5176] = 1,
        [228266] = 20,
        [194024] = 1,
        [269343] = 1,
        [200846] = 1,
        [5697] = 24,
        [165962] = 58,
        [199471] = 1,
        [188778] = 1,
        [188683] = 1,
        [188672] = 1,
        [188651] = 1,
        [201473] = 98,
        [188647] = 1,
        [202466] = 1,
        [214368] = 1,
        [211916] = 1,
        [188639] = 1,
        [187318] = 1,
        [188635] = 1,
        [8122] = 18,
        [1464] = 1,
        [115943] = 1,
        [199472] = 1,
        [152262] = 100,
        [287283] = 55,
        [115946] = 1,
        [115767] = 1,
        [199736] = 1,
        [191034] = 40,
        [207167] = 58,
        [212056] = 66,
        [214629] = 1,
        [236457] = 30,
        [233750] = 48,
        [278841] = 1,
        [260309] = 15,
        [196447] = 100,
        [287719] = 1,
        [204190] = 40,
        [207118] = 1,
        [198247] = 1,
        [277787] = 60,
        [194315] = 1,
        [205184] = 90,
        [108503] = 90,
        [35717] = 66,
        [265187] = 80,
        [111771] = 80,
        [286231] = 1,
        [14062] = 30,
        [191048] = 1,
        [216868] = 40,
        [287717] = 1,
        [77220] = 78,
        [82245] = 1,
        [198103] = 36,
        [198248] = 1,
        [185086] = 1,
        [197488] = 45,
        [77215] = 78,
        [6789] = 75,
        [279779] = 1,
        [187313] = 1,
        [286229] = 1,
        [268358] = 75,
        [77485] = 78,
        [233752] = 40,
        [231811] = 70,
        [198296] = 1,
        [30283] = 60,
        [197256] = 1,
        [5308] = 8,
        [270545] = 60,
        [267170] = 60,
        [264119] = 60,
        [197604] = 1,
        [269352] = 42,
        [205179] = 60,
        [287722] = 1,
        [197241] = 1,
        [207684] = 105,
        [273326] = 1,
        [196408] = 60,
        [196226] = 60,
        [48265] = 55,
        [279778] = 1,
        [207088] = 1,
        [1122] = 58,
        [1833] = 8,
        [223306] = 15,
        [1098] = 56,
        [5246] = 70,
        [272891] = 1,
        [238069] = 1,
        [194018] = 1,
        [69820] = 20,
        [231792] = 52,
        [273328] = 1,
        [108415] = 52,
        [79206] = 38,
        [86091] = 50,
        [117013] = 90,
        [111400] = 45,
        [108416] = 45,
        [205673] = 70,
        [273327] = 1,
        [698] = 42,
        [228477] = 98,
        [234877] = 40,
        [272893] = 1,
        [184092] = 40,
        [51490] = 24,
        [210663] = 1,
        [233581] = 40,
        [198236] = 1,
        [233577] = 40,
        [185565] = 10,
        [221711] = 40,
        [269357] = 55,
        [5784] = 20,
        [546] = 32,
        [210650] = 1,
        [212623] = 40,
        [212618] = 40,
        [77223] = 78,
        [8647] = 26,
        [212459] = 40,
        [56315] = 44,
        [197244] = 1,
        [212371] = 40,
        [212295] = 40,
        [212282] = 40,
        [115675] = 1,
        [201996] = 40,
        [212635] = 1,
        [53480] = 40,
        [45243] = 38,
        [119898] = 38,
        [199325] = 40,
        [188070] = 5,
        [238105] = 1,
        [266134] = 30,
        [265412] = 30,
        [264130] = 30,
        [218612] = 104,
        [115939] = 50,
        [205145] = 30,
        [198238] = 1,
        [202226] = 40,
        [674] = 55,
        [197915] = 45,
        [212638] = 40,
        [220831] = 98,
        [202126] = 40,
        [17877] = 30,
        [192544] = 55,
        [712] = 28,
        [275381] = 1,
        [215381] = 1,
        [5740] = 26,
        [231791] = 26,
        [231996] = 1,
        [77486] = 78,
        [189059] = 1,
        [755] = 22,
        [198736] = 1,
        [642] = 18,
        [112104] = 1,
        [201467] = 98,
        [211910] = 1,
        [192543] = 55,
        [697] = 20,
        [213400] = 40,
        [200474] = 1,
        [48792] = 57,
        [216860] = 40,
        [117198] = 19,
        [6201] = 18,
        [117014] = 15,
        [6353] = 15,
        [206431] = 40,
        [267171] = 15,
        [253593] = 56,
        [130736] = 60,
        [201468] = 98,
        [196258] = 1,
        [192542] = 55,
        [264106] = 15,
        [241205] = 1,
        [287303] = 55,
        [264078] = 15,
        [210918] = 70,
        [198590] = 15,
        [1449] = 18,
        [197248] = 1,
        [108558] = 15,
        [30108] = 14,
        [287302] = 1,
        [275388] = 1,
        [195266] = 1,
        [193532] = 30,
        [201469] = 98,
        [5221] = 8,
        [58104] = 1,
        [199483] = 45,
        [122278] = 75,
        [236716] = 10,
        [184843] = 1,
        [30146] = 12,
        [116858] = 12,
        [980] = 10,
        [212407] = 1,
        [348] = 10,
        [198120] = 40,
        [195265] = 1,
        [193531] = 45,
        [61999] = 72,
        [201470] = 98,
        [49184] = 55,
        [686] = 1,
        [199484] = 40,
        [63312] = 1,
        [243188] = 98,
        [275389] = 1,
        [202727] = 55,
        [203224] = 40,
        [194026] = 1,
        [287802] = 1,
        [197762] = 1,
        [198032] = 40,
        [205495] = 1,
        [193530] = 40,
        [287822] = 1,
        [213652] = 75,
        [201471] = 98,
        [287658] = 1,
        [202464] = 1,
        [199485] = 1,
        [280207] = 1,
        [275391] = 1,
        [279911] = 1,
        [279879] = 1,
        [73920] = 40,
        [196770] = 57,
        [279673] = 1,
        [279650] = 1,
        [278747] = 1,
        [277705] = 1,
        [192538] = 55,
        [275376] = 1,
        [201472] = 98,
        [231785] = 70,
        [278309] = 60,
        [273526] = 1,
        [273524] = 1,
        [85804] = 90,
        [205691] = 40,
        [273522] = 1,
        [274369] = 1,
        [263165] = 90,
        [272892] = 1,
        [275892] = 1,
        [270647] = 1,
        [221841] = 1,
        [246997] = 1,
        [200] = 1,
        [82242] = 1,
        [287805] = 1,
        [197268] = 40,
        [221887] = 1,
        [241257] = 1,
        [273409] = 1,
        [287251] = 1,
        [19574] = 20,
        [48778] = 55,
        [241252] = 1,
        [132469] = 60,
        [274837] = 100,
        [120679] = 15,
        [212894] = 98,
        [287250] = 55,
        [240264] = 1,
        [228545] = 1,
        [241203] = 1,
        [238074] = 1,
        [238072] = 1,
        [232670] = 1,
        [77226] = 78,
        [214931] = 1,
        [221882] = 1,
        [187827] = 98,
        [228049] = 70,
        [287775] = 1,
        [69826] = 40,
        [210676] = 1,
        [125972] = 6,
        [52610] = 75,
        [219455] = 1,
        [199401] = 1,
        [125050] = 40,
        [30449] = 70,
        [223829] = 55,
        [219424] = 1,
        [219415] = 1,
        [36554] = 22,
        [1515] = 13,
        [289237] = 10,
        [221351] = 98,
        [219195] = 1,
        [218572] = 1,
        [216698] = 1,
        [115181] = 40,
        [287360] = 1,
        [274345] = 98,
        [203974] = 90,
        [214936] = 1,
        [277720] = 1,
        [218607] = 1,
        [281854] = 110,
        [210145] = 1,
        [287253] = 1,
        [211899] = 1,
        [211720] = 1,
        [271534] = 78,
        [231021] = 70,
        [211530] = 1,
        [211219] = 1,
        [207697] = 100,
        [211158] = 1,
        [211144] = 1,
        [211131] = 1,
        [211123] = 1,
        [220357] = 40,
        [211105] = 1,
        [217615] = 45,
        [211099] = 1,
        [62124] = 12,
        [201424] = 1,
        [190567] = 1,
        [2782] = 22,
        [138430] = 1,
        [279875] = 1,
        [199282] = 1,
        [11417] = 42,
        [200733] = 15,
        [190488] = 3,
        [199163] = 1,
        [206940] = 90,
        [199152] = 1,
        [192548] = 55,
        [189080] = 55,
        [216122] = 1,
        [199120] = 1,
        [33917] = 10,
        [199112] = 1,
        [235484] = 42,
        [196675] = 1,
        [213644] = 22,
        [200311] = 1,
        [278386] = 98,
        [196305] = 1,
        [196301] = 1,
        [193786] = 10,
        [196236] = 1,
        [196227] = 1,
        [196222] = 1,
        [196211] = 1,
        [50769] = 14,
        [258920] = 100,
        [262624] = 100,
        [214634] = 1,
        [202224] = 60,
        [203962] = 15,
        [740] = 80,
        [236501] = 40,
        [197995] = 100,
        [53344] = 55,
        [275906] = 1,
        [273424] = 1,
        [191634] = 100,
        [188089] = 100,
        [193537] = 15,
        [8679] = 54,
        [157154] = 100,
        [207206] = 1,
        [210666] = 1,
        [197781] = 1,
        [19750] = 5,
        [114050] = 100,
        [32546] = 75,
        [280614] = 90,
        [187837] = 1,
        [214903] = 55,
        [275908] = 1,
        [262303] = 90,
        [276837] = 100,
        [197524] = 34,
        [275350] = 98,
        [210714] = 90,
        [277667] = 1,
        [197211] = 90,
        [213410] = 110,
        [196277] = 46,
        [204197] = 90,
        [280609] = 78,
        [203964] = 75,
        [30884] = 75,
        [196029] = 20,
        [192088] = 75,
        [214904] = 55,
        [193539] = 90,
        [274419] = 1,
        [203468] = 98,
        [273453] = 1,
        [290250] = 63,
        [210853] = 60,
        [14914] = 10,
        [207401] = 60,
        [275909] = 1,
        [207399] = 60,
        [198838] = 60,
        [192087] = 60,
        [203965] = 90,
        [231283] = 44,
        [286835] = 55,
        [16166] = 60,
        [287768] = 1,
        [8143] = 58,
        [231723] = 56,
        [204293] = 56,
        [198067] = 56,
        [272872] = 1,
        [286834] = 55,
        [5394] = 14,
        [16864] = 48,
        [273367] = 1,
        [274424] = 1,
        [231780] = 54,
        [233759] = 40,
        [272871] = 1,
        [1680] = 40,
        [86100] = 50,
        [86099] = 50,
        [32182] = 50,
        [56382] = 1,
        [199372] = 1,
        [277663] = 1,
        [195283] = 14,
        [61882] = 48,
        [16196] = 48,
        [192558] = 55,
        [115313] = 90,
        [185358] = 10,
        [205224] = 55,
        [5782] = 16,
        [265046] = 45,
        [239293] = 1,
        [198505] = 1,
        [556] = 44,
        [192310] = 1,
        [264000] = 100,
        [274425] = 1,
        [277902] = 1,
        [193796] = 12,
        [277784] = 42,
        [192557] = 55,
        [277778] = 42,
        [287771] = 40,
        [211015] = 42,
        [205223] = 56,
        [208683] = 20,
        [211010] = 42,
        [211004] = 42,
        [73630] = 40,
        [239295] = 1,
        [498] = 32,
        [204437] = 40,
        [264002] = 102,
        [277904] = 1,
        [202246] = 40,
        [204403] = 40,
        [120] = 34,
        [204398] = 40,
        [233754] = 40,
        [275917] = 55,
        [204393] = 40,
        [204331] = 40,
        [191565] = 55,
        [202743] = 90,
        [238067] = 1,
        [204247] = 40,
        [243435] = 55,
        [49576] = 55,
        [264004] = 108,
        [205209] = 55,
        [115399] = 45,
        [197590] = 70,
        [184364] = 36,
        [266921] = 75,
        [3562] = 17,
        [233755] = 24,
        [100] = 3,
        [280391] = 75,
        [274432] = 1,
        [77219] = 78,
        [279829] = 1,
        [187707] = 32,
        [211913] = 1,
        [51533] = 34,
        [197779] = 1,
        [242707] = 1,
        [123986] = 15,
        [271232] = 32,
        [189086] = 55,
        [279830] = 1,
        [287773] = 1,
        [260897] = 30,
        [204219] = 1,
        [188838] = 3,
        [210643] = 30,
        [200076] = 30,
        [278904] = 1,
        [197992] = 30,
        [13819] = 20,
        [207197] = 98,
        [192058] = 44,
        [19236] = 26,
        [77472] = 24,
        [33757] = 24,
        [61336] = 36,
        [198013] = 98,
        [203227] = 1,
        [241202] = 1,
        [231721] = 20,
        [2645] = 16,
        [246035] = 15,
        [201900] = 15,
        [77606] = 55,
        [213572] = 1,
        [204979] = 40,
        [203724] = 98,
        [207200] = 75,
        [231042] = 54,
        [200071] = 15,
        [31850] = 50,
        [214664] = 1,
        [202731] = 55,
        [31884] = 80,
        [287777] = 1,
        [51485] = 45,
        [275863] = 1,
        [192424] = 1,
        [117906] = 78,
        [185368] = 1,
        [221844] = 1,
        [86629] = 10,
        [8042] = 10,
        [193063] = 30,
        [287784] = 1,
        [202996] = 1,
        [61295] = 10,
        [60103] = 10,
        [212182] = 40,
        [225092] = 1,
        [195292] = 58,
        [44425] = 10,
        [192567] = 55,
        [187828] = 10,
        [132621] = 90,
        [206967] = 60,
        [8004] = 5,
        [199257] = 1,
        [188389] = 3,
        [58135] = 1,
        [191328] = 1,
        [231691] = 66,
        [287801] = 1,
        [287778] = 1,
        [221862] = 1,
        [31661] = 32,
        [199754] = 26,
        [48707] = 57,
        [287300] = 1,
        [286949] = 1,
        [279504] = 1,
        [117907] = 78,
        [274442] = 1,
        [278697] = 1,
        [53142] = 74,
        [278095] = 1,
        [214915] = 1,
        [192318] = 1,
        [26573] = 14,
        [198265] = 40,
        [200515] = 1,
        [276152] = 1,
        [190336] = 13,
        [198529] = 40,
        [197632] = 45,
        [275858] = 1,
        [277926] = 1,
        [275393] = 1,
        [274444] = 1,
        [274416] = 1,
        [289339] = 55,
        [2637] = 66,
        [191602] = 1,
        [214916] = 1,
        [288843] = 63,
        [370] = 63,
        [274443] = 1,
        [116849] = 35,
        [32379] = 75,
        [273449] = 1,
        [227683] = 1,
        [116847] = 90,
        [231627] = 70,
        [273389] = 1,
        [205234] = 40,
        [274446] = 1,
        [272992] = 1,
        [214913] = 1,
        [1044] = 38,
        [231663] = 42,
        [272978] = 1,
        [269570] = 1,
        [269567] = 1,
        [274445] = 1,
        [109186] = 75,
        [155580] = 15,
        [273887] = 15,
        [264121] = 1,
        [264113] = 1,
        [288848] = 75,
        [195304] = 98,
        [281400] = 110,
        [263792] = 1,
        [231040] = 52,
        [214914] = 1,
        [54729] = 55,
        [287790] = 1,
        [242652] = 1,
        [51886] = 22,
        [96231] = 35,
        [710] = 32,
        [213161] = 1,
        [212668] = 40,
        [196779] = 1,
        [153595] = 90,
        [53140] = 60,
        [2825] = 50,
        [231793] = 52,
        [213658] = 40,
        [195452] = 20,
        [219213] = 1,
        [215414] = 1,
        [194312] = 1,
        [212436] = 30,
        [53209] = 30,
        [214933] = 1,
        [155578] = 90,
        [214932] = 1,
        [224103] = 1,
        [212636] = 1,
        [203747] = 98,
        [210033] = 1,
        [210032] = 1,
        [210031] = 1,
        [281404] = 110,
        [207362] = 1,
        [207360] = 1,
        [221856] = 1,
        [6991] = 13,
        [214920] = 1,
        [207357] = 1,
        [207356] = 1,
        [189092] = 55,
        [207355] = 1,
        [207354] = 1,
        [202755] = 1,
        [207351] = 1,
        [191569] = 1,
        [207285] = 1,
        [6673] = 42,
        [281402] = 110,
        [48181] = 90,
        [207092] = 1,
        [214917] = 1,
        [279855] = 1,
        [201995] = 55,
        [199528] = 30,
        [152108] = 60,
        [274391] = 1,
        [56246] = 1,
        [78674] = 10,
        [198367] = 1,
        [195300] = 1,
        [203749] = 1,
        [207264] = 57,
        [214621] = 15,
        [273461] = 1,
        [79008] = 60,
        [116844] = 60,
        [121471] = 56,
        [214918] = 1,
        [191584] = 55,
        [192630] = 1,
        [114333] = 1,
        [273464] = 1,
        [191861] = 1,
        [191717] = 1,
        [272968] = 1,
        [279854] = 1,
        [122] = 5,
        [214907] = 98,
        [221622] = 70,
        [273463] = 1,
        [197047] = 1,
        [260331] = 100,
        [107428] = 10,
        [191582] = 1,
        [227684] = 1,
        [191572] = 1,
        [66907] = 20,
        [288795] = 1,
        [147783] = 1,
        [51690] = 100,
        [195298] = 1,
        [272970] = 1,
        [209694] = 12,
        [287356] = 1,
        [185123] = 98,
        [47528] = 62,
        [273465] = 1,
        [216890] = 40,
        [32267] = 42,
        [272969] = 1,
        [245687] = 90,
        [238104] = 90,
        [114165] = 75,
        [236019] = 40,
        [273468] = 1,
        [192077] = 75,
        [212462] = 1,
        [186773] = 1,
        [193225] = 100,
        [285381] = 90,
        [193315] = 10,
        [257621] = 50,
        [288800] = 1,
        [76806] = 78,
        [76803] = 78,
        [279921] = 1,
        [120146] = 74,
        [23161] = 40,
        [257505] = 75,
        [236020] = 40,
        [256165] = 75,
        [196861] = 75,
        [154904] = 75,
        [131511] = 75,
        [231063] = 44,
        [214906] = 55,
        [108216] = 75,
        [257620] = 14,
        [57934] = 70,
        [31230] = 60,
        [114018] = 68,
        [403] = 1,
        [269498] = 1,
        [281403] = 110,
        [155835] = 15,
        [196055] = 98,
        [13877] = 63,
        [1860] = 62,
        [205228] = 60,
        [192570] = 55,
        [231064] = 44,
        [203242] = 40,
        [201] = 1,
        [214911] = 1,
        [238098] = 1,
        [198292] = 1,
        [233275] = 1,
        [205723] = 100,
        [232546] = 40,
        [280716] = 60,
        [200759] = 60,
        [193546] = 60,
        [8921] = 3,
        [231057] = 56,
        [197007] = 56,
        [213682] = 1,
        [202746] = 40,
        [13750] = 56,
        [231716] = 52,
        [79096] = 50,
        [214912] = 1,
        [57954] = 1,
        [58423] = 50,
        [195243] = 1,
        [1856] = 48,
        [227322] = 102,
        [242580] = 45,
        [2836] = 42,
        [202514] = 1,
        [231718] = 42,
        [273476] = 1,
        [2094] = 24,
        [53] = 10,
        [209218] = 1,
        [214909] = 98,
        [236776] = 40,
        [191577] = 1,
        [213981] = 40,
        [273130] = 1,
        [193223] = 100,
        [273032] = 1,
        [207777] = 40,
        [194318] = 1,
        [207736] = 40,
        [198952] = 40,
        [198092] = 40,
        [58094] = 1,
        [198020] = 40,
        [197038] = 1,
        [209217] = 1,
        [1459] = 58,
        [214910] = 1,
        [197899] = 40,
        [76808] = 78,
        [339] = 24,
        [201259] = 40,
        [193316] = 40,
        [275463] = 1,
        [185313] = 40,
        [236273] = 40,
        [191592] = 55,
        [3408] = 38,
        [1725] = 38,
        [273131] = 1,
        [2983] = 32,
        [206970] = 75,
        [209220] = 1,
        [137013] = 1,
        [255989] = 30,
        [161800] = 65,
        [196924] = 30,
        [120145] = 71,
        [231549] = 85,
        [205727] = 60,
        [146652] = 55,
        [14190] = 28,
        [2096] = 13,
        [189097] = 55,
        [14161] = 28,
        [5277] = 26,
        [186372] = 1,
        [277950] = 40,
        [116841] = 30,
        [1804] = 24,
        [241134] = 1,
        [202021] = 15,
        [212431] = 30,
        [286392] = 1,
        [231550] = 65,
        [122470] = 55,
        [278784] = 1,
        [53270] = 65,
        [224841] = 1,
        [1943] = 20,
        [11419] = 42,
        [202797] = 40,
        [185311] = 16,
        [200758] = 15,
        [93322] = 10,
        [44614] = 20,
        [198148] = 57,
        [279877] = 13,
        [191837] = 40,
        [236012] = 40,
        [287321] = 55,
        [56377] = 90,
        [219630] = 1,
        [279876] = 12,
        [231055] = 52,
        [53600] = 20,
        [185438] = 12,
        [236068] = 100,
        [61329] = 10,
        [206476] = 110,
        [226829] = 1,
        [161797] = 76,
        [269513] = 40,
        [213180] = 1,
        [286832] = 55,
        [56641] = 1,
        [2823] = 10,
        [2098] = 10,
        [277953] = 75,
        [1784] = 5,
        [124502] = 32,
        [195072] = 98,
        [202770] = 100,
        [286393] = 1,
        [288985] = 1,
        [273488] = 1,
        [286581] = 1,
        [206974] = 58,
        [189110] = 98,
        [202769] = 1,
        [286579] = 1,
        [199045] = 40,
        [286130] = 1,
        [279752] = 1,
        [191339] = 1,
        [278675] = 1,
        [278666] = 1,
        [216424] = 1,
        [277723] = 1,
        [214935] = 1,
        [199542] = 40,
        [279387] = 1,
        [206478] = 99,
        [277958] = 1,
        [209223] = 1,
        [162794] = 98,
        [231546] = 48,
        [273419] = 1,
        [261947] = 45,
        [231050] = 32,
        [264057] = 60,
        [277957] = 1,
        [195295] = 1,
        [1752] = 1,
        [196061] = 1,
        [192081] = 20,
        [212451] = 1,
        [109304] = 24,
        [206477] = 108,
        [210148] = 1,
        [270627] = 1,
        [269308] = 1,
        [272934] = 1,
        [195317] = 1,
        [241154] = 1,
        [288882] = 98,
        [241153] = 1,
        [197061] = 90,
        [475] = 28,
        [198054] = 45,
        [272933] = 1,
        [2484] = 8,
        [80240] = 40,
        [204261] = 40,
        [238066] = 1,
        [200025] = 100,
        [196555] = 104,
        [202155] = 45,
        [272936] = 1,
        [231548] = 54,
        [53343] = 55,
        [275975] = 1,
        [231052] = 25,
        [214930] = 1,
        [214929] = 1,
        [47536] = 50,
        [272935] = 1,
        [214934] = 1,
        [209835] = 1,
        [287830] = 1,
        [289022] = 40,
        [209781] = 1,
        [202897] = 1,
        [116705] = 35,
        [195315] = 1,
        [202820] = 1,
        [189849] = 1,
        [214923] = 1,
        [210702] = 1,
        [241253] = 1,
        [202533] = 1,
        [278643] = 1,
        [198074] = 1,
        [224466] = 55,
        [288343] = 1,
        [258860] = 106,
        [204263] = 60,
        [93321] = 10,
        [202507] = 1,
        [277966] = 1,
        [202463] = 1,
        [272940] = 1,
        [197239] = 1,
        [1494] = 4,
        [214924] = 1,
        [131768] = 34,
        [197235] = 1,
        [192759] = 1,
        [2008] = 14,
        [191598] = 1,
        [192376] = 1,
        [192349] = 1,
        [204264] = 40,
        [214428] = 1,
        [192329] = 1,
        [192326] = 1,
        [126745] = 1,
        [192323] = 1,
        [226359] = 98,
        [128595] = 20,
        [5116] = 4,
        [199532] = 100,
        [287337] = 1,
        [192315] = 1,
        [277905] = 1,
        [146662] = 1,
        [280711] = 100,
        [64129] = 30,
        [265202] = 100,
        [238063] = 100,
        [107059] = 1,
        [200183] = 100,
        [197050] = 40,
        [212210] = 40,
        [272944] = 1,
        [214922] = 1,
        [58875] = 80,
        [153561] = 100,
        [110744] = 90,
        [64901] = 85,
        [211714] = 1,
        [201430] = 90,
        [209216] = 1,
        [62618] = 70,
        [203754] = 1,
        [207230] = 60,
        [187880] = 40,
        [209480] = 1,
        [64044] = 60,
        [204018] = 60,
        [190852] = 1,
        [205369] = 60,
        [200294] = 1,
        [224871] = 74,
        [205367] = 60,
        [200199] = 60,
        [127933] = 40,
        [1079] = 20,
        [288340] = 1,
        [287355] = 1,
        [196819] = 3,
        [203755] = 1,
        [210722] = 1,
        [190356] = 18,
        [236499] = 52,
        [201769] = 40,
        [204019] = 15,
        [15487] = 52,
        [233059] = 1,
        [12051] = 20,
        [214928] = 1,
        [191594] = 55,
        [196559] = 50,
        [238558] = 45,
        [238136] = 45,
        [200209] = 45,
        [209730] = 40,
        [197045] = 45,
        [202530] = 1,
        [231065] = 65,
        [209389] = 1,
        [88423] = 22,
        [47788] = 44,
        [196602] = 44,
        [224869] = 71,
        [200296] = 1,
        [191593] = 55,
        [605] = 42,
        [258887] = 106,
        [203524] = 1,
        [198807] = 40,
        [1463] = 45,
        [289657] = 40,
        [280750] = 40,
        [102560] = 75,
        [235587] = 40,
        [275930] = 55,
        [273448] = 1,
        [586] = 44,
        [220143] = 55,
        [210575] = 1,
        [214926] = 1,
        [209780] = 40,
        [204254] = 98,
        [275929] = 55,
        [199259] = 40,
        [281390] = 1,
        [288342] = 1,
        [238053] = 1,
        [183415] = 60,
        [273946] = 57,
        [197535] = 40,
        [197815] = 1,
        [186387] = 26,
        [200546] = 40,
        [198793] = 98,
        [195323] = 1,
        [199786] = 100,
        [189857] = 1,
        [235297] = 30,
        [275931] = 55,
        [231688] = 36,
        [231565] = 56,
        [231687] = 36,
        [9484] = 34,
        [20711] = 32,
        [85256] = 10,
        [1706] = 32,
        [271466] = 100,
        [275934] = 98,
        [288733] = 30,
        [235189] = 30,
        [195322] = 1,
        [120224] = 50,
        [190719] = 28,
        [48045] = 26,
        [178940] = 98,
        [222644] = 1,
        [194331] = 1,
        [187874] = 28,
        [34914] = 24,
        [231070] = 55,
        [202767] = 1,
        [278480] = 55,
        [11420] = 42,
        [2060] = 24,
        [2948] = 14,
        [236788] = 40,
        [21562] = 22,
        [213634] = 22,
        [63733] = 20,
        [278479] = 55,
        [228264] = 20,
        [275935] = 98,
        [20484] = 42,
        [197073] = 90,
        [228260] = 20,
        [221883] = 1,
        [185916] = 20,
        [273952] = 75,
        [188632] = 1,
        [262861] = 16,
        [265259] = 15,
        [198299] = 1,
        [203513] = 98,
        [205351] = 15,
        [200153] = 15,
        [3567] = 17,
        [2006] = 14,
        [232698] = 12,
        [123040] = 45,
        [231568] = 18,
        [47540] = 10,
        [189870] = 1,
        [247454] = 108,
        [231832] = 30,
        [273140] = 1,
        [210727] = 60,
        [269555] = 1,
        [206491] = 110,
        [257891] = 60,
        [258881] = 102,
        [2061] = 5,
        [589] = 3,
        [273953] = 90,
        [585] = 1,
        [202521] = 1,
        [203018] = 1,
        [215183] = 1,
        [277925] = 100,
        [198068] = 58,
        [287340] = 1,
        [61780] = 1,
        [260367] = 60,
        [287336] = 1,
        [278902] = 1,
        [129250] = 45,
        [31821] = 70,
        [278629] = 1,
        [277906] = 1,
        [277682] = 1,
        [275542] = 1,
        [202522] = 1,
        [222648] = 1,
        [273521] = 1,
        [192345] = 1,
        [272780] = 1,
        [209226] = 1,
        [272775] = 1,
        [203283] = 40,
        [270649] = 1,
        [115008] = 30,
        [17] = 8,
        [254236] = 1,
        [215941] = 100,
        [241149] = 1,
        [238099] = 1,
        [287247] = 1,
        [113656] = 20,
        [210716] = 1,
        [46917] = 10,
        [231827] = 28,
        [203757] = 1,
        [209225] = 1,
        [219655] = 1,
        [203284] = 40,
        [216212] = 1,
        [215322] = 1,
        [288855] = 55,
        [11366] = 12,
        [214927] = 1,
        [214925] = 1,
        [153626] = 100,
        [213200] = 40,
        [222646] = 1,
        [202524] = 1,
        [114052] = 100,
        [241270] = 1,
        [197716] = 1,
        [221886] = 1,
        [197715] = 1,
        [197713] = 1,
        [202028] = 90,
        [288853] = 82,
        [197708] = 1,
        [198304] = 28,
        [18499] = 44,
        [6544] = 26,
        [164547] = 1,
        [279918] = 1,
        [111673] = 69,
        [203782] = 98,
        [196434] = 1,
        [241269] = 1,
        [221885] = 1,
        [198817] = 40,
        [268501] = 15,
        [123830] = 1,
        [203286] = 40,
        [258876] = 100,
        [196358] = 1,
        [231564] = 34,
        [186396] = 1,
        [184662] = 32,
        [6807] = 10,
        [273034] = 1,
        [61721] = 60,
        [194179] = 1,
        [203783] = 98,
        [131784] = 1,
        [193645] = 1,
        [197080] = 1,
        [193643] = 1,
        [224122] = 1,
        [199380] = 1,
        [89744] = 50,
        [186393] = 1,
        [147776] = 1,
        [219669] = 1,
        [126094] = 1,
        [107906] = 1,
        [84963] = 100,
        [214937] = 1,
        [227691] = 1,
        [102558] = 75,
        [207739] = 100,
        [115636] = 78,
        [156910] = 100,
        [123829] = 1,
        [209229] = 1,
        [248033] = 90,
        [205026] = 15,
        [202031] = 15,
        [218910] = 98,
        [202] = 1,
        [215661] = 90,
        [210191] = 90,
        [29838] = 60,
        [269561] = 1,
        [214938] = 1,
        [76671] = 78,
        [200806] = 90,
        [86659] = 70,
        [47585] = 28,
        [421] = 28,
        [34769] = 20,
        [278573] = 1,
        [213220] = 48,
        [89745] = 50,
        [209224] = 1,
        [270670] = 1,
        [199324] = 60,
        [238134] = 1,
        [202296] = 15,
        [86103] = 50,
        [119996] = 80,
        [275773] = 3,
        [216853] = 56,
        [199452] = 56,
        [218931] = 55,
        [203538] = 58,
        [31589] = 32,
        [86102] = 50,
        [272977] = 1,
        [205028] = 60,
        [274963] = 100,
        [192106] = 15,
        [234299] = 45,
        [187708] = 28,
        [32223] = 44,
        [204035] = 30,
        [272980] = 1,
        [270100] = 52,
        [203275] = 40,
        [204268] = 42,
        [66906] = 40,
        [34767] = 40,
        [203539] = 65,
        [23214] = 40,
        [272979] = 1,
        [1180] = 1,
        [216327] = 40,
        [287940] = 1,
        [215652] = 40,
        [210294] = 40,
        [287378] = 1,
        [207028] = 40,
        [198062] = 40,
        [204914] = 40,
        [108238] = 30,
        [199441] = 40,
        [276021] = 1,
        [108370] = 34,
        [281482] = 90,
        [121183] = 40,
        [210476] = 65,
        [272981] = 1,
        [205030] = 60,
        [287938] = 1,
        [272906] = 34,
        [24275] = 30,
        [168534] = 29,
        [272904] = 1,
        [204023] = 30,
        [269569] = 15,
        [280189] = 1,
        [12950] = 55,
        [276023] = 60,
        [114154] = 30,
        [8737] = 1,
        [85043] = 25,
        [202577] = 40,
        [272983] = 98,
        [205029] = 60,
        [194844] = 100,
        [3714] = 66,
        [279503] = 55,
        [73629] = 20,
        [196578] = 1,
        [240270] = 1,
        [198064] = 40,
        [272986] = 98,
        [230332] = 30,
        [235313] = 26,
        [781] = 8,
        [209483] = 1,
        [267610] = 15,
        [196082] = 1,
        [275529] = 1,
        [272985] = 98,
        [205032] = 60,
        [114158] = 15,
        [7328] = 14,
        [194595] = 100,
        [241264] = 1,
        [114051] = 100,
        [6940] = 56,
        [20271] = 3,
        [92322] = 1,
        [246975] = 1,
        [279502] = 55,
        [219432] = 1,
        [48438] = 40,
        [57979] = 1,
        [275531] = 1,
        [193108] = 1,
        [287269] = 1,
        [196840] = 38,
        [203776] = 30,
        [279406] = 1,
        [273481] = 1,
        [5487] = 10,
        [278785] = 1,
        [34026] = 10,
        [199804] = 20,
        [189144] = 55,
        [287947] = 40,
        [185164] = 98,
        [288880] = 98,
        [278147] = 1,
        [130] = 38,
        [285958] = 1,
        [209749] = 40,
        [231847] = 38,
        [288826] = 80,
        [49028] = 57,
        [152152] = 90,
        [276111] = 1,
        [275468] = 1,
        [275466] = 1,
        [278951] = 1,
        [273142] = 1,
        [278513] = 1,
        [2050] = 10,
        [288878] = 98,
        [195352] = 1,
        [32645] = 36,
        [212217] = 40,
        [1822] = 12,
        [209752] = 40,
        [200302] = 1,
        [273027] = 1,
        [199573] = 1,
        [272976] = 1,
        [214202] = 30,
        [270596] = 1,
        [164815] = 16,
        [269243] = 1,
        [278515] = 1,
        [254473] = 1,
        [195351] = 1,
        [238056] = 1,
        [774] = 10,
        [238049] = 1,
        [254469] = 1,
        [107574] = 90,
        [211489] = 98,
        [241146] = 1,
        [195291] = 1,
        [31687] = 12,
        [289874] = 40,
        [33763] = 20,
        [239042] = 1,
        [239294] = 1,
        [260878] = 45,
        [207269] = 57,
        [183425] = 60,
        [238055] = 1,
        [117216] = 10,
        [238132] = 1,
        [245751] = 61,
        [259391] = 100,
        [280011] = 55,
        [238096] = 1,
        [210182] = 1,
        [279449] = 98,
        [238061] = 1,
        [238060] = 1,
        [246972] = 1,
        [213574] = 1,
        [238050] = 1,
        [205022] = 15,
        [207272] = 56,
        [279450] = 98,
        [200072] = 15,
        [213570] = 1,
        [188644] = 1,
        [211915] = 1,
        [211914] = 1,
        [211912] = 1,
        [202043] = 40,
        [209474] = 1,
        [137010] = 1,
        [214205] = 40,
        [271014] = 100,
        [209376] = 1,
        [280010] = 55,
        [209740] = 40,
        [274426] = 1,
        [203797] = 60,
        [209202] = 1,
        [213480] = 98,
        [207604] = 1,
        [115176] = 65,
        [200654] = 1,
        [200326] = 1,
        [213183] = 1,
        [77575] = 55,
        [242155] = 1,
        [137011] = 1,
        [196586] = 1,
        [200298] = 1,
        [193058] = 1,
        [238052] = 1,
        [205024] = 15,
        [207375] = 98,
        [288417] = 55,
        [274441] = 1,
        [186927] = 1,
        [31224] = 80,
        [278958] = 1,
        [184778] = 1,
        [270581] = 45,
        [184759] = 1,
        [182234] = 1,
        [137012] = 1,
        [145205] = 70,
        [179546] = 1,
        [199330] = 60,
        [238051] = 1,
        [274057] = 55,
        [280197] = 100,
        [274909] = 100,
        [259387] = 90,
        [280515] = 75,
        [207025] = 40,
        [197895] = 100,
        [196736] = 100,
        [210730] = 1,
        [187650] = 18,
        [212640] = 40,
        [196740] = 90,
        [238046] = 98,
        [195345] = 1,
        [123904] = 90,
        [84714] = 57,
        [273006] = 1,
        [974] = 45,
        [216255] = 80,
        [278531] = 1,
        [101643] = 80,
        [261767] = 75,
        [277969] = 1,
        [122783] = 75,
        [273005] = 1,
        [80353] = 80,
        [216519] = 70,
        [278532] = 1,
        [241018] = 55,
        [205273] = 1,
        [198898] = 60,
        [202107] = 55,
        [239304] = 1,
        [51667] = 20,
        [3563] = 17,
        [278529] = 1,
        [120227] = 50,
        [183435] = 70,
        [203553] = 20,
        [195676] = 48,
        [273007] = 1,
        [14983] = 45,
        [196103] = 30,
        [278530] = 1,
        [115396] = 45,
        [208253] = 1,
        [281231] = 42,
        [60188] = 34,
        [132620] = 90,
        [107570] = 30,
        [245013] = 10,
        [45524] = 56,
        [115098] = 15,
        [209584] = 40,
        [82326] = 25,
        [202523] = 40,
        [202370] = 40,
        [202272] = 40,
        [196102] = 30,
        [201318] = 40,
        [278536] = 1,
        [238047] = 1,
        [215223] = 1,
        [157411] = 38,
        [262647] = 30,
        [231605] = 32,
        [126895] = 30,
        [200327] = 85,
        [227635] = 98,
        [279468] = 1,
        [19577] = 26,
        [207029] = 98,
        [178976] = 98,
        [49360] = 42,
        [238042] = 55,
        [115078] = 25,
        [278534] = 55,
        [261917] = 22,
        [218164] = 22,
        [115450] = 22,
        [120517] = 90,
        [126892] = 14,
        [115178] = 14,
        [115546] = 13,
        [231602] = 12,
        [278539] = 1,
        [176246] = 92,
        [203556] = 108,
        [124682] = 12,
        [260404] = 100,
        [205523] = 10,
        [286979] = 55,
        [121253] = 10,
        [12982] = 14,
        [189147] = 55,
        [192384] = 1,
        [116670] = 8,
        [204053] = 100,
        [288634] = 1,
        [286978] = 55,
        [287829] = 1,
        [278537] = 1,
        [287055] = 1,
        [2120] = 20,
        [280386] = 1,
        [279605] = 1,
        [238048] = 1,
        [238044] = 55,
        [278576] = 1,
        [278538] = 1,
        [207778] = 90,
        [783] = 18,
        [276025] = 1,
        [207018] = 55,
        [219183] = 1,
        [274774] = 1,
        [241136] = 1,
        [8676] = 22,
        [278543] = 55,
        [236058] = 75,
        [279442] = 98,
        [274570] = 1,
        [272026] = 100,
        [238043] = 55,
        [19883] = 4,
        [200315] = 1,
        [203791] = 100,
        [750] = 1,
        [227690] = 1,
        [207017] = 40,
        [195354] = 1,
        [248744] = 40,
        [228630] = 40,
        [219513] = 1,
        [278541] = 1,
        [219510] = 1,
        [214921] = 1,
        [214516] = 1,
        [202302] = 1,
        [49361] = 52,
        [125931] = 1,
        [200316] = 1,
        [278482] = 55,
        [213136] = 1,
        [213133] = 1,
        [209997] = 40,
        [205406] = 1,
        [199563] = 1,
        [176242] = 92,
        [219445] = 1,
        [193371] = 1,
        [279540] = 1,
        [238070] = 1,
        [219678] = 1,
        [191637] = 55,
        [241047] = 55,
        [239296] = 1,
        [195269] = 1,
        [278484] = 55,
        [217200] = 12,
        [195267] = 1,
        [35551] = 50,
        [210000] = 32,
        [61648] = 40,
        [116680] = 50,
        [125151] = 1,
        [196607] = 15,
        [100780] = 1,
        [197835] = 63,
        [205021] = 100,
        [157997] = 15,
        [155147] = 100,
        [155148] = 100,
        [116812] = 1,
        [176248] = 92,
        [205023] = 90,
        [210725] = 90,
        [205037] = 90,
        [114301] = 1,
        [86949] = 52,
        [273088] = 55,
        [176244] = 92,
        [205036] = 75,
        [195615] = 1,
        [132626] = 90,
        [239290] = 1,
        [247483] = 40,
        [114923] = 90,
        [33891] = 75,
        [88346] = 85,
        [88345] = 85,
        [288973] = 98,
        [279541] = 1,
        [219436] = 1,
        [196611] = 63,
        [265145] = 55,
        [285933] = 80,
        [49358] = 52,
        [76657] = 78,
        [278487] = 55,
        [212653] = 30,
        [238071] = 1,
        [277792] = 60,
        [201458] = 98,
        [6770] = 14,
        [209258] = 110,
        [205025] = 54,
        [161355] = 1,
        [231584] = 48,
        [231567] = 48,
        [137025] = 1,
        [265147] = 55,
        [66] = 42,
        [256170] = 90,
        [209753] = 40,
        [11418] = 42,
        [278489] = 55,
        [12323] = 32,
        [203052] = 40,
        [203280] = 40,
        [208762] = 1,
        [288424] = 55,
        [198151] = 40,
        [161354] = 1,
        [198144] = 40,
        [198126] = 40,
        [246985] = 10,
        [190319] = 40,
        [12042] = 40,
        [231582] = 36,
        [238065] = 1,
        [231596] = 32,
        [196355] = 1,
        [33690] = 62,
        [239291] = 1,
        [190447] = 28,
        [2139] = 22,
        [255937] = 60,
        [273093] = 55,
        [274597] = 1,
        [193134] = 15,
        [197343] = 1,
        [189154] = 55,
        [19884] = 4,
        [203550] = 99,
        [205800] = 40,
        [32272] = 17,
        [238068] = 1,
        [205027] = 15,
        [278493] = 98,
        [205020] = 15,
        [279552] = 1,
        [155149] = 100,
        [527] = 22,
        [30455] = 10,
        [191647] = 1,
        [211509] = 98,
        [56384] = 1,
        [289311] = 1,
        [288803] = 1,
        [273344] = 1,
        [278542] = 1,
        [193876] = 50,
        [49359] = 17,
        [83244] = 57,
        [278495] = 1,
        [274379] = 1,
        [272932] = 1,
        [270671] = 1,
        [146959] = 1,
        [238054] = 1,
        [6196] = 13,
        [220817] = 1,
        [215463] = 1,
        [214919] = 1,
        [152175] = 100,
        [238062] = 1,
        [288425] = 55,
        [195448] = 1,
        [266086] = 90,
        [194314] = 1,
        [194313] = 1,
        [194239] = 1,
        [102543] = 75,
        [260393] = 90,
        [203235] = 40,
        [187321] = 1,
        [269624] = 1,
        [161353] = 1,
        [146976] = 1,
        [278500] = 98,
        [116] = 1,
        [209525] = 10,
        [191384] = 100,
        [260402] = 90,
        [204065] = 75,
        [269625] = 1,
        [83245] = 80,
        [199530] = 90,
        [33691] = 66,
        [206910] = 1,
        [193533] = 60,
        [262839] = 52,
        [199921] = 45,
        [248443] = 40,
        [236077] = 40,
        [152173] = 100,
        [278502] = 98,
        [208652] = 40,
        [238064] = 1,
        [22568] = 10,
        [204066] = 100,
        [187680] = 1,
        [202914] = 40,
        [1766] = 18,
        [278501] = 98,
        [219459] = 1,
        [260240] = 34,
        [287503] = 40,
        [147362] = 32,
        [260228] = 30,
        [5384] = 28,
        [198589] = 98,
        [115750] = 45,
        [276084] = 1,
        [81136] = 63,
        [119582] = 28,
        [214743] = 98,
        [257044] = 20,
        [2643] = 16,
        [265895] = 15,
        [270562] = 20,
        [83242] = 13,
        [1462] = 13,
        [136] = 13,
        [19434] = 12,
        [193640] = 15,
        [259489] = 10,
        [238058] = 1,
        [5011] = 1,
        [288571] = 1,
        [194878] = 56,
        [282143] = 1,
        [189164] = 55,
        [214744] = 98,
        [279807] = 1,
        [195621] = 55,
        [270564] = 20,
        [278505] = 1,
        [277653] = 1,
        [274590] = 1,
        [18562] = 12,
        [186934] = 1,
        [264198] = 1,
        [238057] = 1,
        [273231] = 98,
        [216230] = 1,
        [197862] = 40,
        [229533] = 1,
        [215779] = 1,
        [278074] = 1,
        [209281] = 106,
        [273048] = 63,
        [212410] = 1,
        [278507] = 1,
        [257944] = 60,
        [205154] = 1,
        [145722] = 1,
        [203752] = 1,
        [202316] = 45,
        [203578] = 1,
        [46584] = 55,
        [194912] = 90,
        [278510] = 1,
        [203415] = 1,
        [289314] = 1,
        [197178] = 1,
        [197139] = 1,
        [190520] = 1,
        [274902] = 100,
        [79152] = 10,
        [278509] = 1,
        [528] = 56,
        [78675] = 80,
        [278075] = 1,
        [114107] = 75,
        [20707] = 44,
        [238059] = 1,
        [139] = 12,
        [22570] = 63,
        [5211] = 60,
        [276029] = 58,
        [49020] = 55,
        [85222] = 40,
        [86104] = 50,
        [210706] = 48,
        [106898] = 50,
        [278511] = 1,
        [194223] = 48,
        [113043] = 48,
        [219693] = 1,
        [278077] = 1,
        [178740] = 98,
        [197491] = 45,
        [209782] = 1,
        [200567] = 40,
        [214996] = 1,
        [200549] = 40,
        [264178] = 22,
        [106951] = 40,
        [252216] = 30,
        [688] = 5,
        [276012] = 18,
        [5215] = 16,
        [199107] = 1,
        [254472] = 1,
        [194378] = 1,
        [238086] = 1,
        [203399] = 10,
        [197911] = 10,
        [63560] = 74,
        [1543] = 38,
        [197354] = 1,
        [157642] = 35,
        [279527] = 1,
        [279471] = 1,
        [278082] = 1,
        [209285] = 1,
        [286027] = 1,
        [238687] = 55,
        [254471] = 1,
        [278577] = 1,
        [227] = 1,
        [238085] = 1,
        [214514] = 1,
        [213428] = 1,
        [210638] = 1,
        [210593] = 1,
        [211522] = 40,
        [210570] = 1,
        [200415] = 1,
        [200400] = 1,
        [200399] = 1,
        [190984] = 1,
        [186320] = 1,
        [206803] = 98,
        [256188] = 30,
        [115746] = 1,
        [203555] = 100,
        [239306] = 1,
        [238088] = 1,
        [238045] = 98,
        [269644] = 15,
        [186944] = 1,
        [204021] = 98,
        [203720] = 98,
        [161372] = 60,
        [201457] = 98,
        [198349] = 1,
        [203563] = 1,
        [275699] = 75,
        [102401] = 30,
        [281001] = 45,
        [194909] = 60,
        [114556] = 100,
        [239305] = 1,
        [238087] = 1,
        [186941] = 1,
        [214736] = 1,
        [275541] = 1
    }

    --> CREATE SPEC DB
    -----------------------------------------------------------------------
    weizPVP.SpecDB = {
        --> DEMON HUNTER: HAVOC
        [200166] = 577,
        [206491] = 577,
        [196555] = 577,
        [196718] = 577,
        [198793] = 577,
        [162243] = 577,
        [213241] = 577,
        [213243] = 577,
        [179057] = 577,
        [188499] = 577,
        [198013] = 577,
        [201467] = 577,
        [178963] = 577,
        [162794] = 577,
        [211881] = 577,
        [201427] = 577,
        [210152] = 577,
        --> DEMON HUNTER: VENGEANCE
        [187827] = 581,
        [207684] = 581,
        [203782] = 581,
        [203720] = 581,
        [218256] = 581,
        [203798] = 581,
        [202137] = 581,
        [204490] = 581,
        [204596] = 581,
        [204598] = 581,
        [204021] = 581,
        [202138] = 581,
        [207407] = 581,
        --> DEATH KNIGHT: UNHOLY
        [275699] = 252,
        [42650] = 252,
        [48743] = 252,
        [165395] = 252,
        [49206] = 252,
        [63560] = 252,
        [85948] = 252,
        [49572] = 252,
        [55090] = 252,
        [46584] = 252,
        [51160] = 252,
        --> DEATH KNIGHT: FROST
        [152279] = 251,
        [47568] = 251,
        [279302] = 251,
        [207167] = 251,
        [130735] = 251,
        [51271] = 251,
        [49020] = 251,
        [66198] = 251,
        [222024] = 251,
        [49143] = 251,
        [222026] = 251,
        [66196] = 251,
        [49184] = 251,
        --> DEATH KNIGHT: BLOOD
        [108199] = 250,
        [165394] = 250,
        [114866] = 250,
        [49222] = 250,
        [55233] = 250,
        [49028] = 250,
        [48982] = 250,
        [56222] = 250,
        --> DRUID: BALANCE
        [194223] = 102,
        [102560] = 102,
        [48505] = 102,
        [112071] = 102,
        [78675] = 102,
        [93399] = 102,
        [2912] = 102,
        [190984] = 102,
        [78674] = 102,
        [231021] = 102,
        [191034] = 102,
        [24858] = 102,
        [231042] = 102,
        [194153] = 102,
        [279708] = 102,
        --> DRUID: FERAL
        [106951] = 103,
        [102543] = 103,
        [77764] = 103,
        [171746] = 103,
        [22570] = 103,
        [16974] = 103,
        [52610] = 103,
        [5217] = 103,
        [231057] = 103,
        [231055] = 103,
        --> DRUID: GUARDIAN
        [102558] = 104,
        [77761] = 104,
        [99] = 104,
        [270100] = 104,
        [155835] = 104,
        [155578] = 104,
        [80313] = 104,
        [159232] = 104,
        [33745] = 104,
        [135288] = 104,
        [6807] = 104,
        [62606] = 104,
        --> DRUID: RESTO
        [108238] = 105,
        [33891] = 105,
        [197721] = 105,
        [102793] = 105,
        [740] = 105,
        [5176] = 105,
        [102342] = 105,
        [33763] = 105,
        [88423] = 105,
        [145205] = 105,
        --> MONK: BREWMASTER
        [115203] = 268,
        [115176] = 268,
        [157676] = 268,
        [119582] = 268,
        [115308] = 268,
        [115295] = 268,
        [115181] = 268,
        [121253] = 268,
        [115180] = 268,
        --> MONK: WINDWALKER
        [137639] = 269,
        [123904] = 269,
        [152173] = 269,
        [152175] = 269,
        [116095] = 269,
        [122470] = 269,
        [124280] = 269,
        [128595] = 269,
        [101545] = 269,
        [113656] = 269,
        [117418] = 269,
        --> MONK: MISTWEAVER
        [198664] = 270,
        [243435] = 270,
        [115310] = 270,
        [116680] = 270,
        [115460] = 270,
        [116670] = 270,
        [115294] = 270,
        [116849] = 270,
        [115151] = 270,
        [124682] = 270,
        [115175] = 270,
        --> PALLY: HOLY
        [216331] = 65,
        [498] = 65,
        [105809] = 65,
        [156910] = 65,
        [157007] = 65,
        [85222] = 65,
        [31821] = 65,
        [82326] = 65,
        [148039] = 65,
        [53563] = 65,
        [82327] = 65,
        [2812] = 65,
        [20473] = 65,
        --> PALLY: PROT
        [31850] = 66,
        [86659] = 66,
        [204018] = 66,
        [6940] = 66,
        [204150] = 66,
        [53600] = 66,
        [119072] = 66,
        [31935] = 66,
        --> PALLY: RET
        [231895] = 70,
        [184662] = 70,
        [1044] = 70,
        [853] = 70,
        [115750] = 70,
        [157048] = 70,
        [20164] = 70,
        [879] = 70,
        [53385] = 70,
        [224266] = 70,
        [224239] = 70,
        [184575] = 70,
        --> PRIEST: DISC
        [123040] = 256,
        [271466] = 256,
        [152118] = 256,
        [62618] = 256,
        [194509] = 256,
        [129250] = 256,
        [33206] = 256,
        [81751] = 256,
        [94472] = 256,
        [47750] = 256,
        [214621] = 256,
        [200829] = 256,
        [47536] = 256,
        [204197] = 256,
        --> PRIEST: HOLY
        [200183] = 257,
        [64844] = 257,
        [64901] = 257,
        [265202] = 257,
        [155245] = 257,
        [64843] = 257,
        [34861] = 257,
        [32546] = 257,
        [596] = 257,
        [88625] = 257,
        [2050] = 257,
        [47788] = 257,
        [139] = 257,
        [2061] = 257,
        [2060] = 257,
        --> PRIEST: SHADOW
        [34433] = 258,
        [200174] = 258,
        [193223] = 258,
        [47585] = 258,
        [64044] = 258,
        [15286] = 258,
        [32379] = 258,
        [73510] = 258,
        [78203] = 258,
        [34914] = 258,
        [8092] = 258,
        [15407] = 258,
        [228266] = 258,
        [228260] = 258,
        --> SHAMAN: ELE
        [198067] = 262,
        [192249] = 262,
        [114050] = 262,
        [108281] = 262,
        [165399] = 262,
        [165477] = 262,
        [165339] = 262,
        [165462] = 262,
        [170374] = 262,
        [61882] = 262,
        [77756] = 262,
        [86108] = 262,
        [88766] = 262,
        [60188] = 262,
        [29000] = 262,
        [62099] = 262,
        [123099] = 262,
        [51490] = 262,
        [8042] = 262,
        --> SHAMAN: ENHANCE
        [165368] = 263,
        [117012] = 263,
        [165341] = 263,
        [73680] = 263,
        [77223] = 263,
        [51533] = 263,
        [58875] = 263,
        [51530] = 263,
        [86099] = 263,
        [1535] = 263,
        [8190] = 263,
        [166221] = 263,
        [33757] = 263,
        [17364] = 263,
        [32175] = 263,
        [32176] = 263,
        [16282] = 263,
        [86629] = 263,
        [10400] = 263,
        [10444] = 263,
        [60103] = 263,
        [30814] = 263,
        [51522] = 263,
        --> SHAMAN: RESTO
        [73920] = 264,
        [231780] = 264,
        [212048] = 264,
        [79206] = 264,
        [114051] = 264,
        [114052] = 264,
        [207399] = 264,
        [157153] = 264,
        [157154] = 264,
        [165391] = 264,
        [165479] = 264,
        [165344] = 264,
        [77226] = 264,
        [98008] = 264,
        [108280] = 264,
        [77472] = 264,
        [86100] = 264,
        [51564] = 264,
        [1064] = 264,
        [16196] = 264,
        [974] = 264,
        [52127] = 264,
        [77130] = 264,
        [55453] = 264,
        [95862] = 264,
        [16213] = 264,
        [61295] = 264,
        [112858] = 264,
        --> WARRIOR: ARMS
        [227847] = 71,
        [152277] = 71,
        [118038] = 71,
        [165365] = 71,
        [167105] = 71,
        [12328] = 71,
        [86101] = 71,
        [1464] = 71,
        [56636] = 71,
        [12294] = 71,
        [12712] = 71,
        [772] = 71,
        [174737] = 71,
        --> WARRIOR: FURY
        [1719] = 72,
        [46924] = 72,
        [184364] = 72,
        [165383] = 72,
        [12950] = 72,
        [46915] = 72,
        [86110] = 72,
        [169679] = 72,
        [169683] = 72,
        [81099] = 72,
        [85288] = 72,
        [12323] = 72,
        [100130] = 72,
        [23881] = 72,
        [23588] = 72,
        [46917] = 72,
        --> WARRIOR: PROT
        [228920] = 73,
        [152276] = 73,
        [159362] = 73,
        [165393] = 73,
        [114192] = 73,
        [76857] = 73,
        [161798] = 73,
        [84608] = 73,
        [1160] = 73,
        [86535] = 73,
        [871] = 73,
        [169680] = 73,
        [169685] = 73,
        [12975] = 73,
        [6572] = 73,
        [20243] = 73,
        [2565] = 73,
        [161608] = 73,
        [23922] = 73,
        [46953] = 73,
        [122509] = 73,
        [29144] = 73,
        [157497] = 73,
        [6343] = 73,
        [71] = 73,
        [157494] = 73
    }
end



--> Player Data Tables
--> Cache of players while they are still could be on the nearby list.

-------------------------------------------------------------------------------
--> Default Options
-------------------------------------------------------------------------------
weizPVP.defaults =  {}
local defaults
do
    defaults = {
        profile = {
            Options = {
                DB_VERSION = "3.0",
                DEBUG = false,
                Addon = {
                    Enabled = true,
                    Visable = true,
                    EnabledInBattlegrounds = true,
                    EnabledInArena = false,
                    Halted = false,
                    VersionSplashSeen = false
                },
                Window = {
                    Locked = false,
                    Pinned = false,
                    Collapsed = false
                },
                --> LagMode
                LagMode = {
                    Enabled = false,
                    Active = false,
                    FPSThreshold = 30,
                    HaltEnabled = false,
                    HaltActive = false
                },
                --> Alerts
                AudioAlerts = {
                    DetectedPlayerSound = false,
                    DetectedPlayerSoundFile = "weizPVP: Notice 1"
                },
                --> Bars
                Bars = {
                    MaxNumBars = 24,
                    AlphaDead = 0.8,
                    AlphaInactive = 0.6,
                    AlphaDefault = 1,
                    RowHeight = 18,
                    VerticalSpacing = 1,
                    Texture = "weizPVP: StatusBar",
                    HighlightTexture = "weizPVP: StatusBar-Highlight",
                    BackgroundTexture = "weizPVP: Bar-BG",
                    NameFont = "Accidental Presidency",
                    NameFontSize = 16,
                    LevelFont = "Accidental Presidency Italic",
                    LevelFontSize = 16,
                    GuildFont = "Accidental Presidency",
                    GuildFontSize = 14
                },
                --> Sorting
                Sorting = {
                    NearbyInactiveTimeout = 32,
                    NearbyActiveTimeout = 20
                },
                --> Frames
                Frames = {
                    BackgroundTexture = "weizPVP: Background",
                    BorderTexture = "weizPVP: Border",
                    BackgroundColor = {
                        0,
                        0,
                        0,
                        0.6
                    },
                    Width = 220,
                    Height = 216,
                    X = 1518,
                    Y = 790,
                    Scale = 1,
                    BorderSize = 4,
                    AutoResize = false,
                    --> Scroll Frame
                    Scroll = {
                        Height = 0
                    },
                    --> List Frame
                    List = {
                        Height = 0
                    },
                    --> Header Frame
                    Header = {
                        Height = 26,
                        Font = "Roboto Condensed BoldItalic",
                        FontSize = 18,
                        FontOutline = "OUTLINE"
                    },
                    --> Footer Frame
                    Footer = {
                        Height = 18,
                        Font = "Accidental Presidency",
                        FontSize = 15,
                        FontOutline = "NONE"
                    }
                },
                --> Stealth Alert
                StealthAlert = {
                    Enabled = true,
                    EnableSound = true,
                    SoundFile = "weizPVP: Warning 1"
                },
                --> Crosshair
                Crosshair = {
                    Enabled = true,
                    Alpha = 1,
                    OnlyOnKosTargets = false,
                    ShowBountyOverlay = false,
                    ColorOverride = false,
                    ColorOverrideRGBA = {
                        1,
                        0.2,
                        0.2,
                        0.6
                    }
                }
            }
        }
    }

    --> Calculate additional defaults based on the dimentions of other properties
    --: Dynamic values adjusted from other values needed during initial frame construction
    -------------------------------------------------------------------------------
    defaults.profile.Options.Frames.List.Height = defaults.profile.Options.Bars.RowHeight + defaults.profile.Options.Bars.VerticalSpacing
    defaults.profile.Options.Frames.Scroll.Height =
        (defaults.profile.Options.Frames.List.Height * 12) + defaults.profile.Options.Bars.VerticalSpacing
    defaults.profile.Options.Frames.Height = defaults.profile.Options.Frames.Scroll.Height
    defaults.profile.Options.Frames.List.Height = defaults.profile.Options.Frames.List.Height * defaults.profile.Options.Bars.MaxNumBars

    weizPVP.defaults = defaults
end

-------------------------------------------------------------------------------
--> Load DB
-------------------------------------------------------------------------------
function weizPVP:LoadDB()
	C_Timer.After(1, InitDataTables)

    --> LOAD CHARACTER OPTIONS
    weizPVP.charDB = {}
    weizPVP.Options = {}
    weizPVP.charDB = LibStub("AceDB-3.0"):New("weizPVPOptions", defaults, true)
    weizPVP.Options = weizPVP.charDB.profile.Options
    --> LOAD GLOBAL PLAYER DB
    weizPVP.globalDB = {}
    weizPVP.PlayerDB = {}
    weizPVP.globalDB = LibStub("AceDB-3.0"):New("weizPVPDatabase", {}, false)
    weizPVP.PlayerDB = weizPVP.globalDB.global
end

-------------------------------------------------------------------------------
--> INIT CURRENT VALUES
-------------------------------------------------------------------------------
function weizPVP:BuildUIElements()
    --> Create Core Frames and Bars
    weizPVP:CreateCoreFrames()
    weizPVP:CreateBars()
    weizPVP:CreateStatusBar()
    weizPVP:CreateStealthAlertFrame()
    --> Setup Crosshair
    weizPVP:CreateCrosshair()
    if weizPVP.Options.Crosshair.Enabled then
        weizPVP:EnableCrosshair()
    else
        weizPVP:DisableCrosshair()
    end
end
